# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '/Users/anjopagdanganan/visbrain-testing/port-visbrain-0.4.3/sleep_scoring/gui/sleep/interface/gui/sleep_gui.ui'
#
# Created by: PyQt5 UI code generator 5.15.11
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.setWindowModality(QtCore.Qt.NonModal)
        MainWindow.setEnabled(True)
        MainWindow.resize(1628, 872)
        font = QtGui.QFont()
        font.setKerning(True)
        font.setStyleStrategy(QtGui.QFont.PreferDefault)
        MainWindow.setFont(font)
        MainWindow.setTabShape(QtWidgets.QTabWidget.Rounded)
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout(self.centralwidget)
        self.horizontalLayout_2.setContentsMargins(1, 3, 1, 3)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.splitter = QtWidgets.QSplitter(self.centralwidget)
        self.splitter.setOrientation(QtCore.Qt.Horizontal)
        self.splitter.setObjectName("splitter")
        self.q_widget = QtWidgets.QWidget(self.splitter)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.q_widget.sizePolicy().hasHeightForWidth())
        self.q_widget.setSizePolicy(sizePolicy)
        self.q_widget.setMinimumSize(QtCore.QSize(0, 0))
        self.q_widget.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.q_widget.setObjectName("q_widget")
        self.verticalLayout_4 = QtWidgets.QVBoxLayout(self.q_widget)
        self.verticalLayout_4.setSizeConstraint(QtWidgets.QLayout.SetDefaultConstraint)
        self.verticalLayout_4.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_4.setSpacing(0)
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.QuickSettings = QtWidgets.QTabWidget(self.q_widget)
        self.QuickSettings.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.QuickSettings.setAutoFillBackground(False)
        self.QuickSettings.setTabShape(QtWidgets.QTabWidget.Rounded)
        self.QuickSettings.setMovable(True)
        self.QuickSettings.setObjectName("QuickSettings")
        self.q_Panels = QtWidgets.QWidget()
        self.q_Panels.setObjectName("q_Panels")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.q_Panels)
        self.verticalLayout.setObjectName("verticalLayout")
        self.frame = QtWidgets.QFrame(self.q_Panels)
        self.frame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame.setObjectName("frame")
        self.gridLayout_24 = QtWidgets.QGridLayout(self.frame)
        self.gridLayout_24.setObjectName("gridLayout_24")
        self.line_14 = QtWidgets.QFrame(self.frame)
        self.line_14.setMinimumSize(QtCore.QSize(10, 0))
        self.line_14.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_14.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_14.setObjectName("line_14")
        self.gridLayout_24.addWidget(self.line_14, 0, 1, 1, 1)
        self.label_77 = QtWidgets.QLabel(self.frame)
        font = QtGui.QFont()
        font.setItalic(True)
        font.setKerning(True)
        font.setStyleStrategy(QtGui.QFont.PreferDefault)
        self.label_77.setFont(font)
        self.label_77.setObjectName("label_77")
        self.gridLayout_24.addWidget(self.label_77, 0, 0, 1, 1)
        self._pan_pick = QtWidgets.QComboBox(self.frame)
        self._pan_pick.setObjectName("_pan_pick")
        self._pan_pick.addItem("")
        self._pan_pick.addItem("")
        self._pan_pick.addItem("")
        self._pan_pick.addItem("")
        self.gridLayout_24.addWidget(self._pan_pick, 0, 2, 1, 1)
        spacerItem = QtWidgets.QSpacerItem(40, 0, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_24.addItem(spacerItem, 1, 2, 1, 1)
        self.verticalLayout.addWidget(self.frame)
        self._stacked_panels = QtWidgets.QStackedWidget(self.q_Panels)
        self._stacked_panels.setFrameShape(QtWidgets.QFrame.NoFrame)
        self._stacked_panels.setObjectName("_stacked_panels")
        self._channels_page = QtWidgets.QWidget()
        self._channels_page.setObjectName("_channels_page")
        self.verticalLayout_34 = QtWidgets.QVBoxLayout(self._channels_page)
        self.verticalLayout_34.setObjectName("verticalLayout_34")
        self.groupBox = QtWidgets.QGroupBox(self._channels_page)
        self.groupBox.setObjectName("groupBox")
        self.verticalLayout_13 = QtWidgets.QVBoxLayout(self.groupBox)
        self.verticalLayout_13.setContentsMargins(0, -1, 0, -1)
        self.verticalLayout_13.setObjectName("verticalLayout_13")
        self.line_13 = QtWidgets.QFrame(self.groupBox)
        self.line_13.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_13.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_13.setObjectName("line_13")
        self.verticalLayout_13.addWidget(self.line_13)
        self._PanScrollChan = QtWidgets.QScrollArea(self.groupBox)
        self._PanScrollChan.setMinimumSize(QtCore.QSize(0, 0))
        self._PanScrollChan.setFrameShape(QtWidgets.QFrame.Box)
        self._PanScrollChan.setFrameShadow(QtWidgets.QFrame.Sunken)
        self._PanScrollChan.setWidgetResizable(True)
        self._PanScrollChan.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignTop)
        self._PanScrollChan.setObjectName("_PanScrollChan")
        self.scrollAreaWidgetContents_3 = QtWidgets.QWidget()
        self.scrollAreaWidgetContents_3.setGeometry(QtCore.QRect(0, 0, 435, 300))
        self.scrollAreaWidgetContents_3.setObjectName("scrollAreaWidgetContents_3")
        self.verticalLayout_14 = QtWidgets.QVBoxLayout(self.scrollAreaWidgetContents_3)
        self.verticalLayout_14.setObjectName("verticalLayout_14")
        self.widget = QtWidgets.QWidget(self.scrollAreaWidgetContents_3)
        self.widget.setObjectName("widget")
        self.verticalLayout_5 = QtWidgets.QVBoxLayout(self.widget)
        self.verticalLayout_5.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_5.setObjectName("verticalLayout_5")
        self._PanChanLay = QtWidgets.QGridLayout()
        self._PanChanLay.setSizeConstraint(QtWidgets.QLayout.SetMaximumSize)
        self._PanChanLay.setHorizontalSpacing(6)
        self._PanChanLay.setVerticalSpacing(9)
        self._PanChanLay.setObjectName("_PanChanLay")
        self.verticalLayout_5.addLayout(self._PanChanLay)
        self.verticalLayout_14.addWidget(self.widget)
        spacerItem1 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.MinimumExpanding)
        self.verticalLayout_14.addItem(spacerItem1)
        self._PanScrollChan.setWidget(self.scrollAreaWidgetContents_3)
        self.verticalLayout_13.addWidget(self._PanScrollChan)
        self.groupBox_7 = QtWidgets.QGroupBox(self.groupBox)
        self.groupBox_7.setObjectName("groupBox_7")
        self.verticalLayout_28 = QtWidgets.QVBoxLayout(self.groupBox_7)
        self.verticalLayout_28.setContentsMargins(0, -1, 0, -1)
        self.verticalLayout_28.setObjectName("verticalLayout_28")
        self.line_22 = QtWidgets.QFrame(self.groupBox_7)
        self.line_22.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_22.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_22.setObjectName("line_22")
        self.verticalLayout_28.addWidget(self.line_22)
        self.gridLayout_13 = QtWidgets.QGridLayout()
        self.gridLayout_13.setContentsMargins(-1, 0, -1, -1)
        self.gridLayout_13.setObjectName("gridLayout_13")
        self.widget_6 = QtWidgets.QWidget(self.groupBox_7)
        self.widget_6.setObjectName("widget_6")
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout(self.widget_6)
        self.horizontalLayout_4.setContentsMargins(-1, 0, -1, 0)
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self._PanAllAmpMin = QtWidgets.QDoubleSpinBox(self.widget_6)
        self._PanAllAmpMin.setDecimals(1)
        self._PanAllAmpMin.setMaximum(100000.0)
        self._PanAllAmpMin.setProperty("value", 0.0)
        self._PanAllAmpMin.setObjectName("_PanAllAmpMin")
        self.horizontalLayout_4.addWidget(self._PanAllAmpMin)
        self._PanAllAmpMax = QtWidgets.QDoubleSpinBox(self.widget_6)
        self._PanAllAmpMax.setDecimals(1)
        self._PanAllAmpMax.setMinimum(-100000.0)
        self._PanAllAmpMax.setMaximum(100000.0)
        self._PanAllAmpMax.setObjectName("_PanAllAmpMax")
        self.horizontalLayout_4.addWidget(self._PanAllAmpMax)
        self.gridLayout_13.addWidget(self.widget_6, 0, 1, 1, 2)
        self.label_35 = QtWidgets.QLabel(self.groupBox_7)
        self.label_35.setObjectName("label_35")
        self.gridLayout_13.addWidget(self.label_35, 0, 0, 1, 1)
        self._PanAmpAuto = QtWidgets.QCheckBox(self.groupBox_7)
        self._PanAmpAuto.setObjectName("_PanAmpAuto")
        self.gridLayout_13.addWidget(self._PanAmpAuto, 2, 0, 1, 3)
        self._PanAmpSym = QtWidgets.QCheckBox(self.groupBox_7)
        self._PanAmpSym.setChecked(True)
        self._PanAmpSym.setObjectName("_PanAmpSym")
        self.gridLayout_13.addWidget(self._PanAmpSym, 1, 0, 1, 3)
        self.horizontalLayout_23 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_23.setContentsMargins(-1, 0, -1, -1)
        self.horizontalLayout_23.setObjectName("horizontalLayout_23")
        spacerItem2 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_23.addItem(spacerItem2)
        self._PanChanSelectAll = QtWidgets.QPushButton(self.groupBox_7)
        self._PanChanSelectAll.setObjectName("_PanChanSelectAll")
        self.horizontalLayout_23.addWidget(self._PanChanSelectAll)
        spacerItem3 = QtWidgets.QSpacerItem(0, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_23.addItem(spacerItem3)
        self._PanChanDeselectAll = QtWidgets.QPushButton(self.groupBox_7)
        self._PanChanDeselectAll.setObjectName("_PanChanDeselectAll")
        self.horizontalLayout_23.addWidget(self._PanChanDeselectAll)
        spacerItem4 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_23.addItem(spacerItem4)
        self.gridLayout_13.addLayout(self.horizontalLayout_23, 3, 0, 1, 3)
        self.verticalLayout_28.addLayout(self.gridLayout_13)
        self.verticalLayout_13.addWidget(self.groupBox_7)
        self.groupBox_4 = QtWidgets.QGroupBox(self.groupBox)
        self.groupBox_4.setObjectName("groupBox_4")
        self.verticalLayout_10 = QtWidgets.QVBoxLayout(self.groupBox_4)
        self.verticalLayout_10.setContentsMargins(0, -1, 0, -1)
        self.verticalLayout_10.setObjectName("verticalLayout_10")
        self.line_38 = QtWidgets.QFrame(self.groupBox_4)
        self.line_38.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_38.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_38.setObjectName("line_38")
        self.verticalLayout_10.addWidget(self.line_38)
        self.gridLayout_15 = QtWidgets.QGridLayout()
        self.gridLayout_15.setContentsMargins(-1, 0, -1, -1)
        self.gridLayout_15.setObjectName("gridLayout_15")
        self._channels_lw = QtWidgets.QDoubleSpinBox(self.groupBox_4)
        self._channels_lw.setDecimals(1)
        self._channels_lw.setMinimum(1.0)
        self._channels_lw.setMaximum(10.0)
        self._channels_lw.setObjectName("_channels_lw")
        self.gridLayout_15.addWidget(self._channels_lw, 0, 2, 1, 1)
        spacerItem5 = QtWidgets.QSpacerItem(40, 0, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_15.addItem(spacerItem5, 2, 2, 1, 1)
        self.label_36 = QtWidgets.QLabel(self.groupBox_4)
        font = QtGui.QFont()
        font.setItalic(True)
        font.setKerning(True)
        font.setStyleStrategy(QtGui.QFont.PreferDefault)
        self.label_36.setFont(font)
        self.label_36.setObjectName("label_36")
        self.gridLayout_15.addWidget(self.label_36, 0, 0, 1, 1)
        self.line_15 = QtWidgets.QFrame(self.groupBox_4)
        self.line_15.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_15.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_15.setObjectName("line_15")
        self.gridLayout_15.addWidget(self.line_15, 0, 1, 1, 1)
        self._channels_alias = QtWidgets.QCheckBox(self.groupBox_4)
        self._channels_alias.setObjectName("_channels_alias")
        self.gridLayout_15.addWidget(self._channels_alias, 1, 0, 1, 1)
        self.verticalLayout_10.addLayout(self.gridLayout_15)
        self.verticalLayout_13.addWidget(self.groupBox_4)
        self.verticalLayout_34.addWidget(self.groupBox)
        self._stacked_panels.addWidget(self._channels_page)
        self._spec_page = QtWidgets.QWidget()
        self._spec_page.setObjectName("_spec_page")
        self.verticalLayout_35 = QtWidgets.QVBoxLayout(self._spec_page)
        self.verticalLayout_35.setObjectName("verticalLayout_35")
        self.gridLayout_4 = QtWidgets.QGridLayout()
        self.gridLayout_4.setContentsMargins(-1, 0, -1, -1)
        self.gridLayout_4.setObjectName("gridLayout_4")
        self._PanSpecMethod = QtWidgets.QComboBox(self._spec_page)
        self._PanSpecMethod.setObjectName("_PanSpecMethod")
        self._PanSpecMethod.addItem("")
        self._PanSpecMethod.addItem("")
        self._PanSpecMethod.addItem("")
        self.gridLayout_4.addWidget(self._PanSpecMethod, 1, 2, 1, 1)
        self.label_54 = QtWidgets.QLabel(self._spec_page)
        font = QtGui.QFont()
        font.setItalic(True)
        font.setKerning(True)
        font.setStyleStrategy(QtGui.QFont.PreferDefault)
        self.label_54.setFont(font)
        self.label_54.setObjectName("label_54")
        self.gridLayout_4.addWidget(self.label_54, 0, 0, 1, 1)
        self.line_17 = QtWidgets.QFrame(self._spec_page)
        self.line_17.setMinimumSize(QtCore.QSize(10, 0))
        self.line_17.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_17.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_17.setObjectName("line_17")
        self.gridLayout_4.addWidget(self.line_17, 1, 1, 1, 1)
        self.label_73 = QtWidgets.QLabel(self._spec_page)
        font = QtGui.QFont()
        font.setItalic(True)
        font.setKerning(True)
        font.setStyleStrategy(QtGui.QFont.PreferDefault)
        self.label_73.setFont(font)
        self.label_73.setObjectName("label_73")
        self.gridLayout_4.addWidget(self.label_73, 1, 0, 1, 1)
        self.line_18 = QtWidgets.QFrame(self._spec_page)
        self.line_18.setMinimumSize(QtCore.QSize(10, 0))
        self.line_18.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_18.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_18.setObjectName("line_18")
        self.gridLayout_4.addWidget(self.line_18, 2, 1, 1, 1)
        self.label_55 = QtWidgets.QLabel(self._spec_page)
        font = QtGui.QFont()
        font.setItalic(True)
        font.setKerning(True)
        font.setStyleStrategy(QtGui.QFont.PreferDefault)
        self.label_55.setFont(font)
        self.label_55.setObjectName("label_55")
        self.gridLayout_4.addWidget(self.label_55, 3, 0, 1, 1)
        self.line_29 = QtWidgets.QFrame(self._spec_page)
        self.line_29.setMinimumSize(QtCore.QSize(10, 0))
        self.line_29.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_29.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_29.setObjectName("line_29")
        self.gridLayout_4.addWidget(self.line_29, 3, 1, 1, 1)
        self._PanSpecChan = QtWidgets.QComboBox(self._spec_page)
        self._PanSpecChan.setObjectName("_PanSpecChan")
        self.gridLayout_4.addWidget(self._PanSpecChan, 0, 2, 1, 1)
        self.line_8 = QtWidgets.QFrame(self._spec_page)
        self.line_8.setMinimumSize(QtCore.QSize(10, 0))
        self.line_8.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_8.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_8.setObjectName("line_8")
        self.gridLayout_4.addWidget(self.line_8, 0, 1, 1, 1)
        self.label_29 = QtWidgets.QLabel(self._spec_page)
        font = QtGui.QFont()
        font.setItalic(True)
        font.setKerning(True)
        font.setStyleStrategy(QtGui.QFont.PreferDefault)
        self.label_29.setFont(font)
        self.label_29.setObjectName("label_29")
        self.gridLayout_4.addWidget(self.label_29, 2, 0, 1, 1)
        self.gridLayout_6 = QtWidgets.QGridLayout()
        self.gridLayout_6.setObjectName("gridLayout_6")
        self._PanSpecCmap = QtWidgets.QComboBox(self._spec_page)
        self._PanSpecCmap.setObjectName("_PanSpecCmap")
        self.gridLayout_6.addWidget(self._PanSpecCmap, 0, 0, 1, 1)
        self._PanSpecCmapInv = QtWidgets.QCheckBox(self._spec_page)
        self._PanSpecCmapInv.setObjectName("_PanSpecCmapInv")
        self.gridLayout_6.addWidget(self._PanSpecCmapInv, 0, 1, 1, 1)
        self.label_24 = QtWidgets.QLabel(self._spec_page)
        self.label_24.setObjectName("label_24")
        self.gridLayout_6.addWidget(self.label_24, 1, 0, 1, 1)
        self._PanSpecCon = QtWidgets.QDoubleSpinBox(self._spec_page)
        self._PanSpecCon.setDecimals(1)
        self._PanSpecCon.setMinimum(0.0)
        self._PanSpecCon.setMaximum(1.0)
        self._PanSpecCon.setSingleStep(0.1)
        self._PanSpecCon.setProperty("value", 0.5)
        self._PanSpecCon.setObjectName("_PanSpecCon")
        self.gridLayout_6.addWidget(self._PanSpecCon, 1, 1, 1, 1)
        self.gridLayout_4.addLayout(self.gridLayout_6, 2, 2, 1, 1)
        self.gridLayout_12 = QtWidgets.QGridLayout()
        self.gridLayout_12.setObjectName("gridLayout_12")
        spacerItem6 = QtWidgets.QSpacerItem(40, 0, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_12.addItem(spacerItem6, 5, 2, 1, 1)
        self.line_31 = QtWidgets.QFrame(self._spec_page)
        self.line_31.setMinimumSize(QtCore.QSize(10, 0))
        self.line_31.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_31.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_31.setObjectName("line_31")
        self.gridLayout_12.addWidget(self.line_31, 0, 1, 1, 1)
        self.label_74 = QtWidgets.QLabel(self._spec_page)
        font = QtGui.QFont()
        font.setItalic(True)
        font.setKerning(True)
        font.setStyleStrategy(QtGui.QFont.PreferDefault)
        self.label_74.setFont(font)
        self.label_74.setObjectName("label_74")
        self.gridLayout_12.addWidget(self.label_74, 3, 0, 1, 1)
        self._PanSpecInterp = QtWidgets.QComboBox(self._spec_page)
        self._PanSpecInterp.setObjectName("_PanSpecInterp")
        self._PanSpecInterp.addItem("")
        self._PanSpecInterp.addItem("")
        self._PanSpecInterp.addItem("")
        self._PanSpecInterp.addItem("")
        self._PanSpecInterp.addItem("")
        self._PanSpecInterp.addItem("")
        self._PanSpecInterp.addItem("")
        self._PanSpecInterp.addItem("")
        self._PanSpecInterp.addItem("")
        self._PanSpecInterp.addItem("")
        self.gridLayout_12.addWidget(self._PanSpecInterp, 3, 2, 1, 1)
        self.label_15 = QtWidgets.QLabel(self._spec_page)
        font = QtGui.QFont()
        font.setItalic(True)
        font.setKerning(True)
        font.setStyleStrategy(QtGui.QFont.PreferDefault)
        self.label_15.setFont(font)
        self.label_15.setObjectName("label_15")
        self.gridLayout_12.addWidget(self.label_15, 1, 0, 1, 1)
        self._PanSpecNfft = QtWidgets.QDoubleSpinBox(self._spec_page)
        self._PanSpecNfft.setDecimals(1)
        self._PanSpecNfft.setMinimum(0.1)
        self._PanSpecNfft.setMaximum(1000.0)
        self._PanSpecNfft.setProperty("value", 30.0)
        self._PanSpecNfft.setObjectName("_PanSpecNfft")
        self.gridLayout_12.addWidget(self._PanSpecNfft, 0, 2, 1, 1)
        self.line_34 = QtWidgets.QFrame(self._spec_page)
        self.line_34.setMinimumSize(QtCore.QSize(10, 0))
        self.line_34.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_34.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_34.setObjectName("line_34")
        self.gridLayout_12.addWidget(self.line_34, 3, 1, 1, 1)
        self._PanSpecStep = QtWidgets.QDoubleSpinBox(self._spec_page)
        self._PanSpecStep.setDecimals(1)
        self._PanSpecStep.setMaximum(0.8)
        self._PanSpecStep.setSingleStep(0.1)
        self._PanSpecStep.setProperty("value", 0.0)
        self._PanSpecStep.setObjectName("_PanSpecStep")
        self.gridLayout_12.addWidget(self._PanSpecStep, 1, 2, 1, 1)
        self.line_32 = QtWidgets.QFrame(self._spec_page)
        self.line_32.setMinimumSize(QtCore.QSize(10, 0))
        self.line_32.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_32.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_32.setObjectName("line_32")
        self.gridLayout_12.addWidget(self.line_32, 1, 1, 1, 1)
        self.horizontalLayout_24 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_24.setObjectName("horizontalLayout_24")
        self.label_16 = QtWidgets.QLabel(self._spec_page)
        self.label_16.setObjectName("label_16")
        self.horizontalLayout_24.addWidget(self.label_16)
        self._PanSpecFstart = QtWidgets.QDoubleSpinBox(self._spec_page)
        self._PanSpecFstart.setDecimals(1)
        self._PanSpecFstart.setMinimum(0.5)
        self._PanSpecFstart.setMaximum(190.0)
        self._PanSpecFstart.setObjectName("_PanSpecFstart")
        self.horizontalLayout_24.addWidget(self._PanSpecFstart)
        spacerItem7 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_24.addItem(spacerItem7)
        self.label_17 = QtWidgets.QLabel(self._spec_page)
        self.label_17.setObjectName("label_17")
        self.horizontalLayout_24.addWidget(self.label_17)
        self._PanSpecFend = QtWidgets.QDoubleSpinBox(self._spec_page)
        self._PanSpecFend.setDecimals(1)
        self._PanSpecFend.setMinimum(0.1)
        self._PanSpecFend.setMaximum(200.0)
        self._PanSpecFend.setProperty("value", 20.0)
        self._PanSpecFend.setObjectName("_PanSpecFend")
        self.horizontalLayout_24.addWidget(self._PanSpecFend)
        self.gridLayout_12.addLayout(self.horizontalLayout_24, 2, 2, 1, 1)
        self.label_14 = QtWidgets.QLabel(self._spec_page)
        font = QtGui.QFont()
        font.setItalic(True)
        font.setKerning(True)
        font.setStyleStrategy(QtGui.QFont.PreferDefault)
        self.label_14.setFont(font)
        self.label_14.setObjectName("label_14")
        self.gridLayout_12.addWidget(self.label_14, 0, 0, 1, 1)
        self.line_33 = QtWidgets.QFrame(self._spec_page)
        self.line_33.setMinimumSize(QtCore.QSize(10, 0))
        self.line_33.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_33.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_33.setObjectName("line_33")
        self.gridLayout_12.addWidget(self.line_33, 2, 1, 1, 1)
        self.label_32 = QtWidgets.QLabel(self._spec_page)
        font = QtGui.QFont()
        font.setItalic(True)
        font.setKerning(True)
        font.setStyleStrategy(QtGui.QFont.PreferDefault)
        self.label_32.setFont(font)
        self.label_32.setObjectName("label_32")
        self.gridLayout_12.addWidget(self.label_32, 2, 0, 1, 1)
        self._PanSpecNormW = QtWidgets.QWidget(self._spec_page)
        self._PanSpecNormW.setEnabled(False)
        self._PanSpecNormW.setMinimumSize(QtCore.QSize(0, 20))
        self._PanSpecNormW.setObjectName("_PanSpecNormW")
        self.gridLayout_5 = QtWidgets.QGridLayout(self._PanSpecNormW)
        self.gridLayout_5.setContentsMargins(0, 0, 0, 0)
        self.gridLayout_5.setSpacing(0)
        self.gridLayout_5.setObjectName("gridLayout_5")
        self.line_35 = QtWidgets.QFrame(self._PanSpecNormW)
        self.line_35.setMinimumSize(QtCore.QSize(10, 0))
        self.line_35.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_35.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_35.setObjectName("line_35")
        self.gridLayout_5.addWidget(self.line_35, 0, 1, 1, 1)
        self._PanSpecNorm = QtWidgets.QComboBox(self._PanSpecNormW)
        self._PanSpecNorm.setObjectName("_PanSpecNorm")
        self._PanSpecNorm.addItem("")
        self._PanSpecNorm.addItem("")
        self._PanSpecNorm.addItem("")
        self._PanSpecNorm.addItem("")
        self._PanSpecNorm.addItem("")
        self.gridLayout_5.addWidget(self._PanSpecNorm, 0, 2, 1, 1)
        self.label_75 = QtWidgets.QLabel(self._PanSpecNormW)
        font = QtGui.QFont()
        font.setItalic(True)
        font.setKerning(True)
        font.setStyleStrategy(QtGui.QFont.PreferDefault)
        self.label_75.setFont(font)
        self.label_75.setObjectName("label_75")
        self.gridLayout_5.addWidget(self.label_75, 0, 0, 1, 1)
        spacerItem8 = QtWidgets.QSpacerItem(40, 0, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_5.addItem(spacerItem8, 1, 2, 1, 1)
        self.gridLayout_12.addWidget(self._PanSpecNormW, 4, 0, 1, 3)
        self.gridLayout_4.addLayout(self.gridLayout_12, 3, 2, 1, 1)
        self.verticalLayout_35.addLayout(self.gridLayout_4)
        self.horizontalLayout_25 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_25.setObjectName("horizontalLayout_25")
        spacerItem9 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_25.addItem(spacerItem9)
        self._PanSpecApply = QtWidgets.QPushButton(self._spec_page)
        self._PanSpecApply.setObjectName("_PanSpecApply")
        self.horizontalLayout_25.addWidget(self._PanSpecApply)
        spacerItem10 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_25.addItem(spacerItem10)
        self.verticalLayout_35.addLayout(self.horizontalLayout_25)
        spacerItem11 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_35.addItem(spacerItem11)
        self._stacked_panels.addWidget(self._spec_page)
        self._hyp_page = QtWidgets.QWidget()
        self._hyp_page.setObjectName("_hyp_page")
        self.verticalLayout_36 = QtWidgets.QVBoxLayout(self._hyp_page)
        self.verticalLayout_36.setObjectName("verticalLayout_36")
        self.gridLayout_25 = QtWidgets.QGridLayout()
        self.gridLayout_25.setObjectName("gridLayout_25")
        self.label_81 = QtWidgets.QLabel(self._hyp_page)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Maximum, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_81.sizePolicy().hasHeightForWidth())
        self.label_81.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setItalic(True)
        font.setKerning(True)
        font.setStyleStrategy(QtGui.QFont.PreferDefault)
        self.label_81.setFont(font)
        self.label_81.setAlignment(QtCore.Qt.AlignCenter)
        self.label_81.setObjectName("label_81")
        self.gridLayout_25.addWidget(self.label_81, 0, 0, 1, 1)
        self.line_40 = QtWidgets.QFrame(self._hyp_page)
        self.line_40.setMinimumSize(QtCore.QSize(10, 0))
        self.line_40.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_40.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_40.setObjectName("line_40")
        self.gridLayout_25.addWidget(self.line_40, 0, 1, 1, 1)
        self._PanHypnoLw = QtWidgets.QDoubleSpinBox(self._hyp_page)
        self._PanHypnoLw.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self._PanHypnoLw.sizePolicy().hasHeightForWidth())
        self._PanHypnoLw.setSizePolicy(sizePolicy)
        self._PanHypnoLw.setDecimals(0)
        self._PanHypnoLw.setMinimum(1.0)
        self._PanHypnoLw.setMaximum(9.0)
        self._PanHypnoLw.setSingleStep(1.0)
        self._PanHypnoLw.setProperty("value", 2.0)
        self._PanHypnoLw.setObjectName("_PanHypnoLw")
        self.gridLayout_25.addWidget(self._PanHypnoLw, 0, 2, 1, 1)
        self._PanHypnoColor = QtWidgets.QCheckBox(self._hyp_page)
        self._PanHypnoColor.setChecked(True)
        self._PanHypnoColor.setObjectName("_PanHypnoColor")
        self.gridLayout_25.addWidget(self._PanHypnoColor, 1, 0, 1, 3)
        self.verticalLayout_36.addLayout(self.gridLayout_25)
        self.horizontalLayout_6 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_6.setContentsMargins(-1, 0, -1, -1)
        self.horizontalLayout_6.setObjectName("horizontalLayout_6")
        spacerItem12 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_6.addItem(spacerItem12)
        self._PanHypnoReset = QtWidgets.QPushButton(self._hyp_page)
        self._PanHypnoReset.setObjectName("_PanHypnoReset")
        self.horizontalLayout_6.addWidget(self._PanHypnoReset)
        spacerItem13 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_6.addItem(spacerItem13)
        self.verticalLayout_36.addLayout(self.horizontalLayout_6)
        spacerItem14 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_36.addItem(spacerItem14)
        self._stacked_panels.addWidget(self._hyp_page)
        self._topo_page = QtWidgets.QWidget()
        self._topo_page.setObjectName("_topo_page")
        self.verticalLayout_37 = QtWidgets.QVBoxLayout(self._topo_page)
        self.verticalLayout_37.setObjectName("verticalLayout_37")
        self.gridLayout_19 = QtWidgets.QGridLayout()
        self.gridLayout_19.setVerticalSpacing(9)
        self.gridLayout_19.setObjectName("gridLayout_19")
        self.line_27 = QtWidgets.QFrame(self._topo_page)
        self.line_27.setMinimumSize(QtCore.QSize(10, 0))
        self.line_27.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_27.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_27.setObjectName("line_27")
        self.gridLayout_19.addWidget(self.line_27, 1, 1, 1, 1)
        self.line_20 = QtWidgets.QFrame(self._topo_page)
        self.line_20.setMinimumSize(QtCore.QSize(10, 0))
        self.line_20.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_20.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_20.setObjectName("line_20")
        self.gridLayout_19.addWidget(self.line_20, 2, 1, 3, 1)
        self._PanTopoAutoClim = QtWidgets.QCheckBox(self._topo_page)
        self._PanTopoAutoClim.setChecked(True)
        self._PanTopoAutoClim.setObjectName("_PanTopoAutoClim")
        self.gridLayout_19.addWidget(self._PanTopoAutoClim, 2, 2, 1, 6)
        self._PanTopoClimW = QtWidgets.QWidget(self._topo_page)
        self._PanTopoClimW.setMinimumSize(QtCore.QSize(30, 0))
        self._PanTopoClimW.setObjectName("_PanTopoClimW")
        self.horizontalLayout_18 = QtWidgets.QHBoxLayout(self._PanTopoClimW)
        self.horizontalLayout_18.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_18.setSpacing(0)
        self.horizontalLayout_18.setObjectName("horizontalLayout_18")
        self.label_66 = QtWidgets.QLabel(self._PanTopoClimW)
        self.label_66.setObjectName("label_66")
        self.horizontalLayout_18.addWidget(self.label_66)
        self._PanTopoCmin = QtWidgets.QDoubleSpinBox(self._PanTopoClimW)
        self._PanTopoCmin.setDecimals(2)
        self._PanTopoCmin.setMinimum(-1000000.0)
        self._PanTopoCmin.setMaximum(1000000.0)
        self._PanTopoCmin.setProperty("value", -1.0)
        self._PanTopoCmin.setObjectName("_PanTopoCmin")
        self.horizontalLayout_18.addWidget(self._PanTopoCmin)
        self._PanTopoCmax = QtWidgets.QDoubleSpinBox(self._PanTopoClimW)
        self._PanTopoCmax.setDecimals(2)
        self._PanTopoCmax.setMinimum(-1000000.0)
        self._PanTopoCmax.setMaximum(1000000.0)
        self._PanTopoCmax.setProperty("value", 1.0)
        self._PanTopoCmax.setObjectName("_PanTopoCmax")
        self.horizontalLayout_18.addWidget(self._PanTopoCmax)
        self.gridLayout_19.addWidget(self._PanTopoClimW, 3, 2, 1, 6)
        self.label_63 = QtWidgets.QLabel(self._topo_page)
        font = QtGui.QFont()
        font.setItalic(True)
        font.setUnderline(False)
        font.setKerning(True)
        font.setStyleStrategy(QtGui.QFont.PreferDefault)
        self.label_63.setFont(font)
        self.label_63.setObjectName("label_63")
        self.gridLayout_19.addWidget(self.label_63, 2, 0, 3, 1)
        self.widget_9 = QtWidgets.QWidget(self._topo_page)
        self.widget_9.setObjectName("widget_9")
        self.verticalLayout_32 = QtWidgets.QVBoxLayout(self.widget_9)
        self.verticalLayout_32.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_32.setSpacing(0)
        self.verticalLayout_32.setObjectName("verticalLayout_32")
        self.gridLayout_20 = QtWidgets.QGridLayout()
        self.gridLayout_20.setObjectName("gridLayout_20")
        self._PanTopoFW = QtWidgets.QWidget(self.widget_9)
        self._PanTopoFW.setMinimumSize(QtCore.QSize(0, 0))
        self._PanTopoFW.setObjectName("_PanTopoFW")
        self.horizontalLayout_16 = QtWidgets.QHBoxLayout(self._PanTopoFW)
        self.horizontalLayout_16.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_16.setSpacing(0)
        self.horizontalLayout_16.setObjectName("horizontalLayout_16")
        self.label_69 = QtWidgets.QLabel(self._PanTopoFW)
        self.label_69.setObjectName("label_69")
        self.horizontalLayout_16.addWidget(self.label_69)
        self._PanTopoFmin = QtWidgets.QDoubleSpinBox(self._PanTopoFW)
        self._PanTopoFmin.setDecimals(1)
        self._PanTopoFmin.setProperty("value", 12.0)
        self._PanTopoFmin.setObjectName("_PanTopoFmin")
        self.horizontalLayout_16.addWidget(self._PanTopoFmin)
        spacerItem15 = QtWidgets.QSpacerItem(20, 20, QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_16.addItem(spacerItem15)
        self.label_70 = QtWidgets.QLabel(self._PanTopoFW)
        self.label_70.setObjectName("label_70")
        self.horizontalLayout_16.addWidget(self.label_70)
        self._PanTopoFmax = QtWidgets.QDoubleSpinBox(self._PanTopoFW)
        self._PanTopoFmax.setDecimals(1)
        self._PanTopoFmax.setProperty("value", 16.0)
        self._PanTopoFmax.setObjectName("_PanTopoFmax")
        self.horizontalLayout_16.addWidget(self._PanTopoFmax)
        self.gridLayout_20.addWidget(self._PanTopoFW, 1, 0, 1, 2)
        self._PanTopoDisp = QtWidgets.QComboBox(self.widget_9)
        self._PanTopoDisp.setObjectName("_PanTopoDisp")
        self._PanTopoDisp.addItem("")
        self._PanTopoDisp.addItem("")
        self._PanTopoDisp.addItem("")
        self.gridLayout_20.addWidget(self._PanTopoDisp, 0, 0, 1, 2)
        self.verticalLayout_32.addLayout(self.gridLayout_20)
        self.gridLayout_19.addWidget(self.widget_9, 1, 2, 1, 6)
        self.label_65 = QtWidgets.QLabel(self._topo_page)
        font = QtGui.QFont()
        font.setItalic(True)
        font.setKerning(True)
        font.setStyleStrategy(QtGui.QFont.PreferDefault)
        self.label_65.setFont(font)
        self.label_65.setObjectName("label_65")
        self.gridLayout_19.addWidget(self.label_65, 1, 0, 1, 1)
        self.label_67 = QtWidgets.QLabel(self._topo_page)
        self.label_67.setObjectName("label_67")
        self.gridLayout_19.addWidget(self.label_67, 4, 2, 1, 1)
        self._PanTopoRev = QtWidgets.QCheckBox(self._topo_page)
        self._PanTopoRev.setChecked(True)
        self._PanTopoRev.setObjectName("_PanTopoRev")
        self.gridLayout_19.addWidget(self._PanTopoRev, 4, 7, 1, 1)
        self._PanTopoCmap = QtWidgets.QComboBox(self._topo_page)
        self._PanTopoCmap.setObjectName("_PanTopoCmap")
        self.gridLayout_19.addWidget(self._PanTopoCmap, 4, 3, 1, 4)
        self.verticalLayout_37.addLayout(self.gridLayout_19)
        self._PanTopoVizW = QtWidgets.QWidget(self._topo_page)
        self._PanTopoVizW.setEnabled(False)
        self._PanTopoVizW.setMinimumSize(QtCore.QSize(0, 0))
        self._PanTopoVizW.setObjectName("_PanTopoVizW")
        self.verticalLayout_41 = QtWidgets.QVBoxLayout(self._PanTopoVizW)
        self.verticalLayout_41.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_41.setSpacing(0)
        self.verticalLayout_41.setObjectName("verticalLayout_41")
        self.widget_10 = QtWidgets.QWidget(self._PanTopoVizW)
        self.widget_10.setMinimumSize(QtCore.QSize(0, 50))
        self.widget_10.setObjectName("widget_10")
        self.horizontalLayout_17 = QtWidgets.QHBoxLayout(self.widget_10)
        self.horizontalLayout_17.setObjectName("horizontalLayout_17")
        spacerItem16 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_17.addItem(spacerItem16)
        self._PanTopoApply = QtWidgets.QPushButton(self.widget_10)
        self._PanTopoApply.setObjectName("_PanTopoApply")
        self.horizontalLayout_17.addWidget(self._PanTopoApply)
        spacerItem17 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_17.addItem(spacerItem17)
        self.verticalLayout_41.addWidget(self.widget_10)
        self.verticalLayout_37.addWidget(self._PanTopoVizW)
        spacerItem18 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_37.addItem(spacerItem18)
        self._PanTopoVizW.raise_()
        self._stacked_panels.addWidget(self._topo_page)
        self.verticalLayout.addWidget(self._stacked_panels)
        self.QuickSettings.addTab(self.q_Panels, "")
        self.q_Tools = QtWidgets.QWidget()
        self.q_Tools.setObjectName("q_Tools")
        self.verticalLayout_6 = QtWidgets.QVBoxLayout(self.q_Tools)
        self.verticalLayout_6.setObjectName("verticalLayout_6")
        self.frame_2 = QtWidgets.QFrame(self.q_Tools)
        self.frame_2.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.frame_2.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame_2.setObjectName("frame_2")
        self.gridLayout_26 = QtWidgets.QGridLayout(self.frame_2)
        self.gridLayout_26.setObjectName("gridLayout_26")
        self.line_39 = QtWidgets.QFrame(self.frame_2)
        self.line_39.setMinimumSize(QtCore.QSize(10, 0))
        self.line_39.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_39.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_39.setObjectName("line_39")
        self.gridLayout_26.addWidget(self.line_39, 0, 1, 1, 1)
        self.label_78 = QtWidgets.QLabel(self.frame_2)
        font = QtGui.QFont()
        font.setItalic(True)
        font.setKerning(True)
        font.setStyleStrategy(QtGui.QFont.PreferDefault)
        self.label_78.setFont(font)
        self.label_78.setObjectName("label_78")
        self.gridLayout_26.addWidget(self.label_78, 0, 0, 1, 1)
        self._tool_pick = QtWidgets.QComboBox(self.frame_2)
        self._tool_pick.setObjectName("_tool_pick")
        self._tool_pick.addItem("")
        self._tool_pick.addItem("")
        self.gridLayout_26.addWidget(self._tool_pick, 0, 2, 1, 1)
        spacerItem19 = QtWidgets.QSpacerItem(40, 0, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_26.addItem(spacerItem19, 1, 2, 1, 1)
        self.verticalLayout_6.addWidget(self.frame_2)
        self._stacked_tools = QtWidgets.QStackedWidget(self.q_Tools)
        self._stacked_tools.setObjectName("_stacked_tools")
        self._sigproc_page = QtWidgets.QWidget()
        self._sigproc_page.setObjectName("_sigproc_page")
        self.verticalLayout_25 = QtWidgets.QVBoxLayout(self._sigproc_page)
        self.verticalLayout_25.setObjectName("verticalLayout_25")
        self.gridLayout_14 = QtWidgets.QGridLayout()
        self.gridLayout_14.setContentsMargins(-1, 0, -1, -1)
        self.gridLayout_14.setObjectName("gridLayout_14")
        self.label_76 = QtWidgets.QLabel(self._sigproc_page)
        font = QtGui.QFont()
        font.setItalic(True)
        font.setKerning(True)
        font.setStyleStrategy(QtGui.QFont.PreferDefault)
        self.label_76.setFont(font)
        self.label_76.setObjectName("label_76")
        self.gridLayout_14.addWidget(self.label_76, 0, 0, 1, 1)
        self.line_36 = QtWidgets.QFrame(self._sigproc_page)
        self.line_36.setMinimumSize(QtCore.QSize(10, 0))
        self.line_36.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_36.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_36.setObjectName("line_36")
        self.gridLayout_14.addWidget(self.line_36, 0, 1, 1, 1)
        self._SigFiltChan = QtWidgets.QComboBox(self._sigproc_page)
        self._SigFiltChan.setObjectName("_SigFiltChan")
        self._SigFiltChan.addItem("")
        self.gridLayout_14.addWidget(self._SigFiltChan, 0, 2, 1, 1)
        spacerItem20 = QtWidgets.QSpacerItem(40, 0, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_14.addItem(spacerItem20, 1, 2, 1, 1)
        self.verticalLayout_25.addLayout(self.gridLayout_14)
        self.groupBox_5 = QtWidgets.QGroupBox(self._sigproc_page)
        self.groupBox_5.setObjectName("groupBox_5")
        self.verticalLayout_7 = QtWidgets.QVBoxLayout(self.groupBox_5)
        self.verticalLayout_7.setContentsMargins(0, -1, 0, -1)
        self.verticalLayout_7.setObjectName("verticalLayout_7")
        self.line_12 = QtWidgets.QFrame(self.groupBox_5)
        self.line_12.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_12.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_12.setObjectName("line_12")
        self.verticalLayout_7.addWidget(self.line_12)
        self.gridLayout_2 = QtWidgets.QGridLayout()
        self.gridLayout_2.setObjectName("gridLayout_2")
        self._SigMean = QtWidgets.QCheckBox(self.groupBox_5)
        self._SigMean.setObjectName("_SigMean")
        self.gridLayout_2.addWidget(self._SigMean, 0, 0, 1, 1)
        self._SigTrend = QtWidgets.QCheckBox(self.groupBox_5)
        self._SigTrend.setObjectName("_SigTrend")
        self.gridLayout_2.addWidget(self._SigTrend, 0, 1, 1, 1)
        self.verticalLayout_7.addLayout(self.gridLayout_2)
        self.verticalLayout_25.addWidget(self.groupBox_5)
        self._SigFilt = QtWidgets.QGroupBox(self._sigproc_page)
        self._SigFilt.setCheckable(True)
        self._SigFilt.setChecked(False)
        self._SigFilt.setObjectName("_SigFilt")
        self.verticalLayout_8 = QtWidgets.QVBoxLayout(self._SigFilt)
        self.verticalLayout_8.setContentsMargins(0, -1, 0, -1)
        self.verticalLayout_8.setObjectName("verticalLayout_8")
        self.line_11 = QtWidgets.QFrame(self._SigFilt)
        self.line_11.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_11.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_11.setObjectName("line_11")
        self.verticalLayout_8.addWidget(self.line_11)
        self._SigFiltW = QtWidgets.QWidget(self._SigFilt)
        self._SigFiltW.setEnabled(False)
        self._SigFiltW.setObjectName("_SigFiltW")
        self.verticalLayout_9 = QtWidgets.QVBoxLayout(self._SigFiltW)
        self.verticalLayout_9.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_9.setSpacing(0)
        self.verticalLayout_9.setObjectName("verticalLayout_9")
        self.gridLayout_3 = QtWidgets.QGridLayout()
        self.gridLayout_3.setSpacing(9)
        self.gridLayout_3.setObjectName("gridLayout_3")
        self._SigFiltDisp = QtWidgets.QComboBox(self._SigFiltW)
        self._SigFiltDisp.setObjectName("_SigFiltDisp")
        self._SigFiltDisp.addItem("")
        self._SigFiltDisp.addItem("")
        self._SigFiltDisp.addItem("")
        self._SigFiltDisp.addItem("")
        self.gridLayout_3.addWidget(self._SigFiltDisp, 0, 2, 1, 1)
        self.label_18 = QtWidgets.QLabel(self._SigFiltW)
        font = QtGui.QFont()
        font.setItalic(True)
        font.setKerning(True)
        font.setStyleStrategy(QtGui.QFont.PreferDefault)
        self.label_18.setFont(font)
        self.label_18.setObjectName("label_18")
        self.gridLayout_3.addWidget(self.label_18, 1, 0, 1, 1)
        self.label_7 = QtWidgets.QLabel(self._SigFiltW)
        font = QtGui.QFont()
        font.setItalic(True)
        font.setKerning(True)
        font.setStyleStrategy(QtGui.QFont.PreferDefault)
        self.label_7.setFont(font)
        self.label_7.setObjectName("label_7")
        self.gridLayout_3.addWidget(self.label_7, 2, 0, 1, 1)
        self.line_24 = QtWidgets.QFrame(self._SigFiltW)
        self.line_24.setMinimumSize(QtCore.QSize(10, 0))
        self.line_24.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_24.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_24.setObjectName("line_24")
        self.gridLayout_3.addWidget(self.line_24, 2, 1, 1, 1)
        self.line_23 = QtWidgets.QFrame(self._SigFiltW)
        self.line_23.setMinimumSize(QtCore.QSize(10, 0))
        self.line_23.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_23.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_23.setObjectName("line_23")
        self.gridLayout_3.addWidget(self.line_23, 1, 1, 1, 1)
        self.label_68 = QtWidgets.QLabel(self._SigFiltW)
        font = QtGui.QFont()
        font.setItalic(True)
        font.setKerning(True)
        font.setStyleStrategy(QtGui.QFont.PreferDefault)
        self.label_68.setFont(font)
        self.label_68.setObjectName("label_68")
        self.gridLayout_3.addWidget(self.label_68, 0, 0, 1, 1)
        self.line_26 = QtWidgets.QFrame(self._SigFiltW)
        self.line_26.setMinimumSize(QtCore.QSize(10, 0))
        self.line_26.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_26.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_26.setObjectName("line_26")
        self.gridLayout_3.addWidget(self.line_26, 0, 1, 1, 1)
        self.label_58 = QtWidgets.QLabel(self._SigFiltW)
        font = QtGui.QFont()
        font.setItalic(True)
        font.setKerning(True)
        font.setStyleStrategy(QtGui.QFont.PreferDefault)
        self.label_58.setFont(font)
        self.label_58.setObjectName("label_58")
        self.gridLayout_3.addWidget(self.label_58, 3, 0, 1, 1)
        spacerItem21 = QtWidgets.QSpacerItem(40, 0, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_3.addItem(spacerItem21, 4, 2, 1, 1)
        self.widget_5 = QtWidgets.QWidget(self._SigFiltW)
        self.widget_5.setMinimumSize(QtCore.QSize(0, 0))
        self.widget_5.setObjectName("widget_5")
        self.horizontalLayout_12 = QtWidgets.QHBoxLayout(self.widget_5)
        self.horizontalLayout_12.setContentsMargins(-1, 6, -1, -1)
        self.horizontalLayout_12.setObjectName("horizontalLayout_12")
        spacerItem22 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_12.addItem(spacerItem22)
        self._SigFiltApply = QtWidgets.QPushButton(self.widget_5)
        self._SigFiltApply.setObjectName("_SigFiltApply")
        self.horizontalLayout_12.addWidget(self._SigFiltApply)
        spacerItem23 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_12.addItem(spacerItem23)
        self.gridLayout_3.addWidget(self.widget_5, 5, 0, 1, 3)
        self._SigFiltBand = QtWidgets.QComboBox(self._SigFiltW)
        self._SigFiltBand.setObjectName("_SigFiltBand")
        self._SigFiltBand.addItem("")
        self._SigFiltBand.addItem("")
        self._SigFiltBand.addItem("")
        self._SigFiltBand.addItem("")
        self.gridLayout_3.addWidget(self._SigFiltBand, 1, 2, 1, 1)
        self.widget_4 = QtWidgets.QWidget(self._SigFiltW)
        self.widget_4.setObjectName("widget_4")
        self.horizontalLayout_7 = QtWidgets.QHBoxLayout(self.widget_4)
        self.horizontalLayout_7.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_7.setObjectName("horizontalLayout_7")
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_5.setContentsMargins(-1, 0, -1, -1)
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        self.label_9 = QtWidgets.QLabel(self.widget_4)
        self.label_9.setObjectName("label_9")
        self.horizontalLayout_5.addWidget(self.label_9)
        self._SigFiltFrom = QtWidgets.QDoubleSpinBox(self.widget_4)
        self._SigFiltFrom.setDecimals(1)
        self._SigFiltFrom.setMinimum(0.1)
        self._SigFiltFrom.setMaximum(200.0)
        self._SigFiltFrom.setProperty("value", 12.0)
        self._SigFiltFrom.setObjectName("_SigFiltFrom")
        self.horizontalLayout_5.addWidget(self._SigFiltFrom)
        spacerItem24 = QtWidgets.QSpacerItem(20, 20, QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_5.addItem(spacerItem24)
        self._SigFiltTo = QtWidgets.QDoubleSpinBox(self.widget_4)
        self._SigFiltTo.setDecimals(1)
        self._SigFiltTo.setMinimum(0.1)
        self._SigFiltTo.setMaximum(200.0)
        self._SigFiltTo.setProperty("value", 16.0)
        self._SigFiltTo.setObjectName("_SigFiltTo")
        self.horizontalLayout_5.addWidget(self._SigFiltTo)
        self.label_8 = QtWidgets.QLabel(self.widget_4)
        self.label_8.setObjectName("label_8")
        self.horizontalLayout_5.addWidget(self.label_8)
        self.horizontalLayout_7.addLayout(self.horizontalLayout_5)
        self.gridLayout_3.addWidget(self.widget_4, 2, 2, 1, 1)
        self.line_25 = QtWidgets.QFrame(self._SigFiltW)
        self.line_25.setMinimumSize(QtCore.QSize(10, 0))
        self.line_25.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_25.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_25.setObjectName("line_25")
        self.gridLayout_3.addWidget(self.line_25, 3, 1, 1, 1)
        self.gridLayout_10 = QtWidgets.QGridLayout()
        self.gridLayout_10.setContentsMargins(-1, 0, -1, -1)
        self.gridLayout_10.setObjectName("gridLayout_10")
        self.label_10 = QtWidgets.QLabel(self._SigFiltW)
        self.label_10.setObjectName("label_10")
        self.gridLayout_10.addWidget(self.label_10, 0, 0, 1, 1)
        self.label_11 = QtWidgets.QLabel(self._SigFiltW)
        self.label_11.setObjectName("label_11")
        self.gridLayout_10.addWidget(self.label_11, 1, 0, 1, 1)
        self._SigFiltOrder = QtWidgets.QSpinBox(self._SigFiltW)
        self._SigFiltOrder.setMinimum(1)
        self._SigFiltOrder.setMaximum(20)
        self._SigFiltOrder.setProperty("value", 3)
        self._SigFiltOrder.setObjectName("_SigFiltOrder")
        self.gridLayout_10.addWidget(self._SigFiltOrder, 1, 1, 1, 1)
        self._SigFiltMeth = QtWidgets.QComboBox(self._SigFiltW)
        self._SigFiltMeth.setObjectName("_SigFiltMeth")
        self._SigFiltMeth.addItem("")
        self._SigFiltMeth.addItem("")
        self.gridLayout_10.addWidget(self._SigFiltMeth, 0, 1, 1, 1)
        spacerItem25 = QtWidgets.QSpacerItem(40, 0, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_10.addItem(spacerItem25, 2, 1, 1, 1)
        self.gridLayout_3.addLayout(self.gridLayout_10, 3, 2, 1, 1)
        self.verticalLayout_9.addLayout(self.gridLayout_3)
        self.verticalLayout_8.addWidget(self._SigFiltW)
        spacerItem26 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_8.addItem(spacerItem26)
        self.verticalLayout_25.addWidget(self._SigFilt)
        self._stacked_tools.addWidget(self._sigproc_page)
        self.page_4 = QtWidgets.QWidget()
        self.page_4.setObjectName("page_4")
        self.verticalLayout_30 = QtWidgets.QVBoxLayout(self.page_4)
        self.verticalLayout_30.setObjectName("verticalLayout_30")
        self.frame_6 = QtWidgets.QFrame(self.page_4)
        self.frame_6.setMinimumSize(QtCore.QSize(0, 0))
        self.frame_6.setFrameShape(QtWidgets.QFrame.Box)
        self.frame_6.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame_6.setObjectName("frame_6")
        self.horizontalLayout_11 = QtWidgets.QHBoxLayout(self.frame_6)
        self.horizontalLayout_11.setObjectName("horizontalLayout_11")
        self.label_59 = QtWidgets.QLabel(self.frame_6)
        font = QtGui.QFont()
        font.setItalic(True)
        font.setKerning(True)
        font.setStyleStrategy(QtGui.QFont.PreferDefault)
        self.label_59.setFont(font)
        self.label_59.setAlignment(QtCore.Qt.AlignCenter)
        self.label_59.setObjectName("label_59")
        self.horizontalLayout_11.addWidget(self.label_59)
        self.verticalLayout_30.addWidget(self.frame_6)
        self.gridLayout_22 = QtWidgets.QGridLayout()
        self.gridLayout_22.setContentsMargins(-1, 0, -1, -1)
        self.gridLayout_22.setObjectName("gridLayout_22")
        self._ToolsRefIgnore = QtWidgets.QCheckBox(self.page_4)
        self._ToolsRefIgnore.setChecked(True)
        self._ToolsRefIgnore.setObjectName("_ToolsRefIgnore")
        self.gridLayout_22.addWidget(self._ToolsRefIgnore, 2, 3, 1, 2)
        self._ToolsRefSingleW = QtWidgets.QWidget(self.page_4)
        self._ToolsRefSingleW.setMinimumSize(QtCore.QSize(0, 30))
        self._ToolsRefSingleW.setObjectName("_ToolsRefSingleW")
        self.gridLayout_16 = QtWidgets.QGridLayout(self._ToolsRefSingleW)
        self.gridLayout_16.setContentsMargins(0, 0, 0, 0)
        self.gridLayout_16.setSpacing(0)
        self.gridLayout_16.setObjectName("gridLayout_16")
        self.label_56 = QtWidgets.QLabel(self._ToolsRefSingleW)
        self.label_56.setObjectName("label_56")
        self.gridLayout_16.addWidget(self.label_56, 0, 0, 1, 1)
        self._ToolsRefLst = QtWidgets.QComboBox(self._ToolsRefSingleW)
        self._ToolsRefLst.setObjectName("_ToolsRefLst")
        self.gridLayout_16.addWidget(self._ToolsRefLst, 0, 2, 1, 1)
        spacerItem27 = QtWidgets.QSpacerItem(20, 20, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_16.addItem(spacerItem27, 0, 1, 1, 1)
        spacerItem28 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_16.addItem(spacerItem28, 0, 3, 1, 1)
        self.gridLayout_22.addWidget(self._ToolsRefSingleW, 1, 3, 1, 2)
        self.line_6 = QtWidgets.QFrame(self.page_4)
        self.line_6.setMinimumSize(QtCore.QSize(10, 0))
        self.line_6.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_6.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_6.setObjectName("line_6")
        self.gridLayout_22.addWidget(self.line_6, 0, 1, 1, 1)
        self.label_60 = QtWidgets.QLabel(self.page_4)
        font = QtGui.QFont()
        font.setItalic(True)
        font.setKerning(True)
        font.setStyleStrategy(QtGui.QFont.PreferDefault)
        self.label_60.setFont(font)
        self.label_60.setObjectName("label_60")
        self.gridLayout_22.addWidget(self.label_60, 0, 0, 1, 1)
        self.label_61 = QtWidgets.QLabel(self.page_4)
        font = QtGui.QFont()
        font.setItalic(True)
        font.setKerning(True)
        font.setStyleStrategy(QtGui.QFont.PreferDefault)
        self.label_61.setFont(font)
        self.label_61.setObjectName("label_61")
        self.gridLayout_22.addWidget(self.label_61, 1, 0, 3, 1)
        self.line_21 = QtWidgets.QFrame(self.page_4)
        self.line_21.setMinimumSize(QtCore.QSize(10, 0))
        self.line_21.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_21.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_21.setObjectName("line_21")
        self.gridLayout_22.addWidget(self.line_21, 1, 1, 3, 1)
        self._ToolsRefIgn = QtWidgets.QCheckBox(self.page_4)
        self._ToolsRefIgn.setObjectName("_ToolsRefIgn")
        self.gridLayout_22.addWidget(self._ToolsRefIgn, 3, 3, 1, 2)
        self._ToolsRefMeth = QtWidgets.QComboBox(self.page_4)
        self._ToolsRefMeth.setObjectName("_ToolsRefMeth")
        self._ToolsRefMeth.addItem("")
        self._ToolsRefMeth.addItem("")
        self._ToolsRefMeth.addItem("")
        self.gridLayout_22.addWidget(self._ToolsRefMeth, 0, 2, 1, 3)
        self.verticalLayout_30.addLayout(self.gridLayout_22)
        self._ToolsRefGrp = QtWidgets.QWidget(self.page_4)
        self._ToolsRefGrp.setMinimumSize(QtCore.QSize(0, 30))
        self._ToolsRefGrp.setObjectName("_ToolsRefGrp")
        self.verticalLayout_18 = QtWidgets.QVBoxLayout(self._ToolsRefGrp)
        self.verticalLayout_18.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_18.setSpacing(6)
        self.verticalLayout_18.setObjectName("verticalLayout_18")
        self._ToolsRefIgnArea = QtWidgets.QScrollArea(self._ToolsRefGrp)
        self._ToolsRefIgnArea.setMinimumSize(QtCore.QSize(0, 300))
        self._ToolsRefIgnArea.setWidgetResizable(True)
        self._ToolsRefIgnArea.setObjectName("_ToolsRefIgnArea")
        self.scrollAreaWidgetContents = QtWidgets.QWidget()
        self.scrollAreaWidgetContents.setGeometry(QtCore.QRect(0, 0, 443, 298))
        self.scrollAreaWidgetContents.setObjectName("scrollAreaWidgetContents")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.scrollAreaWidgetContents)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self._ToolsRefIgnGrd = QtWidgets.QGridLayout()
        self._ToolsRefIgnGrd.setObjectName("_ToolsRefIgnGrd")
        self.verticalLayout_2.addLayout(self._ToolsRefIgnGrd)
        spacerItem29 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_2.addItem(spacerItem29)
        self._ToolsRefIgnArea.setWidget(self.scrollAreaWidgetContents)
        self.verticalLayout_18.addWidget(self._ToolsRefIgnArea)
        self.horizontalLayout_9 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_9.setContentsMargins(-1, 9, -1, -1)
        self.horizontalLayout_9.setObjectName("horizontalLayout_9")
        spacerItem30 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_9.addItem(spacerItem30)
        self._ToolsRefApply = QtWidgets.QPushButton(self._ToolsRefGrp)
        self._ToolsRefApply.setObjectName("_ToolsRefApply")
        self.horizontalLayout_9.addWidget(self._ToolsRefApply)
        spacerItem31 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_9.addItem(spacerItem31)
        self.verticalLayout_18.addLayout(self.horizontalLayout_9)
        self.verticalLayout_30.addWidget(self._ToolsRefGrp)
        spacerItem32 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_30.addItem(spacerItem32)
        self.frame_6.raise_()
        self._ToolsRefGrp.raise_()
        self._stacked_tools.addWidget(self.page_4)
        self.verticalLayout_6.addWidget(self._stacked_tools)
        self.QuickSettings.addTab(self.q_Tools, "")
        self.q_Info = QtWidgets.QWidget()
        self.q_Info.setObjectName("q_Info")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(self.q_Info)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self._infoTable = QtWidgets.QTableWidget(self.q_Info)
        self._infoTable.setObjectName("_infoTable")
        self._infoTable.setColumnCount(2)
        self._infoTable.setRowCount(0)
        item = QtWidgets.QTableWidgetItem()
        self._infoTable.setHorizontalHeaderItem(0, item)
        item = QtWidgets.QTableWidgetItem()
        self._infoTable.setHorizontalHeaderItem(1, item)
        self._infoTable.horizontalHeader().setStretchLastSection(True)
        self._infoTable.verticalHeader().setStretchLastSection(False)
        self.verticalLayout_3.addWidget(self._infoTable)
        self.QuickSettings.addTab(self.q_Info, "")
        self.q_Score = QtWidgets.QWidget()
        self.q_Score.setObjectName("q_Score")
        self.verticalLayout_29 = QtWidgets.QVBoxLayout(self.q_Score)
        self.verticalLayout_29.setObjectName("verticalLayout_29")
        self._scoreTable = QtWidgets.QTableWidget(self.q_Score)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self._scoreTable.sizePolicy().hasHeightForWidth())
        self._scoreTable.setSizePolicy(sizePolicy)
        self._scoreTable.setObjectName("_scoreTable")
        self._scoreTable.setColumnCount(3)
        self._scoreTable.setRowCount(0)
        item = QtWidgets.QTableWidgetItem()
        self._scoreTable.setHorizontalHeaderItem(0, item)
        item = QtWidgets.QTableWidgetItem()
        self._scoreTable.setHorizontalHeaderItem(1, item)
        item = QtWidgets.QTableWidgetItem()
        self._scoreTable.setHorizontalHeaderItem(2, item)
        self._scoreTable.horizontalHeader().setStretchLastSection(True)
        self.verticalLayout_29.addWidget(self._scoreTable)
        self.horizontalLayout_13 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_13.setContentsMargins(-1, 0, -1, -1)
        self.horizontalLayout_13.setObjectName("horizontalLayout_13")
        spacerItem33 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_13.addItem(spacerItem33)
        self._scoreAdd = QtWidgets.QPushButton(self.q_Score)
        self._scoreAdd.setObjectName("_scoreAdd")
        self.horizontalLayout_13.addWidget(self._scoreAdd)
        spacerItem34 = QtWidgets.QSpacerItem(10, 20, QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_13.addItem(spacerItem34)
        self._scoreRm = QtWidgets.QPushButton(self.q_Score)
        self._scoreRm.setObjectName("_scoreRm")
        self.horizontalLayout_13.addWidget(self._scoreRm)
        spacerItem35 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_13.addItem(spacerItem35)
        self.verticalLayout_29.addLayout(self.horizontalLayout_13)
        self.QuickSettings.addTab(self.q_Score, "")
        self.q_Detection = QtWidgets.QWidget()
        self.q_Detection.setObjectName("q_Detection")
        self.verticalLayout_22 = QtWidgets.QVBoxLayout(self.q_Detection)
        self.verticalLayout_22.setObjectName("verticalLayout_22")
        self._DetectionTab = QtWidgets.QTabWidget(self.q_Detection)
        self._DetectionTab.setObjectName("_DetectionTab")
        self.q_DetectSettings = QtWidgets.QWidget()
        self.q_DetectSettings.setObjectName("q_DetectSettings")
        self.verticalLayout_38 = QtWidgets.QVBoxLayout(self.q_DetectSettings)
        self.verticalLayout_38.setObjectName("verticalLayout_38")
        self.groupBox_3 = QtWidgets.QGroupBox(self.q_DetectSettings)
        self.groupBox_3.setObjectName("groupBox_3")
        self.verticalLayout_33 = QtWidgets.QVBoxLayout(self.groupBox_3)
        self.verticalLayout_33.setContentsMargins(0, -1, 0, -1)
        self.verticalLayout_33.setObjectName("verticalLayout_33")
        self.line_3 = QtWidgets.QFrame(self.groupBox_3)
        self.line_3.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_3.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_3.setObjectName("line_3")
        self.verticalLayout_33.addWidget(self.line_3)
        self.gridLayout = QtWidgets.QGridLayout()
        self.gridLayout.setObjectName("gridLayout")
        self.label_39 = QtWidgets.QLabel(self.groupBox_3)
        font = QtGui.QFont()
        font.setItalic(True)
        font.setKerning(True)
        font.setStyleStrategy(QtGui.QFont.PreferDefault)
        self.label_39.setFont(font)
        self.label_39.setObjectName("label_39")
        self.gridLayout.addWidget(self.label_39, 0, 1, 1, 1)
        self.label_25 = QtWidgets.QLabel(self.groupBox_3)
        self.label_25.setObjectName("label_25")
        self.gridLayout.addWidget(self.label_25, 2, 3, 1, 1)
        self._ToolDetectType = QtWidgets.QComboBox(self.groupBox_3)
        self._ToolDetectType.setObjectName("_ToolDetectType")
        self._ToolDetectType.addItem("")
        self._ToolDetectType.addItem("")
        self._ToolDetectType.addItem("")
        self._ToolDetectType.addItem("")
        self._ToolDetectType.addItem("")
        self._ToolDetectType.addItem("")
        self.gridLayout.addWidget(self._ToolDetectType, 0, 3, 1, 3)
        self.line_9 = QtWidgets.QFrame(self.groupBox_3)
        self.line_9.setMinimumSize(QtCore.QSize(10, 0))
        self.line_9.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_9.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_9.setObjectName("line_9")
        self.gridLayout.addWidget(self.line_9, 1, 2, 3, 1)
        self._ToolRdViz = QtWidgets.QRadioButton(self.groupBox_3)
        self._ToolRdViz.setObjectName("_ToolRdViz")
        self.gridLayout.addWidget(self._ToolRdViz, 1, 4, 1, 1)
        self.line_10 = QtWidgets.QFrame(self.groupBox_3)
        self.line_10.setMinimumSize(QtCore.QSize(10, 0))
        self.line_10.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_10.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_10.setObjectName("line_10")
        self.gridLayout.addWidget(self.line_10, 0, 2, 1, 1)
        self.label_49 = QtWidgets.QLabel(self.groupBox_3)
        font = QtGui.QFont()
        font.setItalic(True)
        font.setKerning(True)
        font.setStyleStrategy(QtGui.QFont.PreferDefault)
        self.label_49.setFont(font)
        self.label_49.setObjectName("label_49")
        self.gridLayout.addWidget(self.label_49, 1, 1, 3, 1)
        self._ToolRdSelected = QtWidgets.QRadioButton(self.groupBox_3)
        self._ToolRdSelected.setChecked(True)
        self._ToolRdSelected.setObjectName("_ToolRdSelected")
        self.gridLayout.addWidget(self._ToolRdSelected, 1, 3, 1, 1)
        self._ToolRdAll = QtWidgets.QRadioButton(self.groupBox_3)
        self._ToolRdAll.setObjectName("_ToolRdAll")
        self.gridLayout.addWidget(self._ToolRdAll, 1, 5, 1, 1)
        self._ToolDetectChan = QtWidgets.QComboBox(self.groupBox_3)
        self._ToolDetectChan.setObjectName("_ToolDetectChan")
        self.gridLayout.addWidget(self._ToolDetectChan, 2, 4, 1, 1)
        spacerItem36 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout.addItem(spacerItem36, 2, 5, 1, 1)
        self.verticalLayout_33.addLayout(self.gridLayout)
        self.verticalLayout_38.addWidget(self.groupBox_3)
        self.groupBox_2 = QtWidgets.QGroupBox(self.q_DetectSettings)
        self.groupBox_2.setObjectName("groupBox_2")
        self.verticalLayout_26 = QtWidgets.QVBoxLayout(self.groupBox_2)
        self.verticalLayout_26.setContentsMargins(0, -1, 0, -1)
        self.verticalLayout_26.setObjectName("verticalLayout_26")
        self.line_4 = QtWidgets.QFrame(self.groupBox_2)
        self.line_4.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_4.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_4.setObjectName("line_4")
        self.verticalLayout_26.addWidget(self.line_4)
        self._stacked_detections = QtWidgets.QStackedWidget(self.groupBox_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Maximum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self._stacked_detections.sizePolicy().hasHeightForWidth())
        self._stacked_detections.setSizePolicy(sizePolicy)
        self._stacked_detections.setObjectName("_stacked_detections")
        self._spin_page = QtWidgets.QWidget()
        self._spin_page.setObjectName("_spin_page")
        self.verticalLayout_19 = QtWidgets.QVBoxLayout(self._spin_page)
        self.verticalLayout_19.setObjectName("verticalLayout_19")
        self.gridLayout_18 = QtWidgets.QGridLayout()
        self.gridLayout_18.setContentsMargins(-1, 0, -1, -1)
        self.gridLayout_18.setObjectName("gridLayout_18")
        self.label_40 = QtWidgets.QLabel(self._spin_page)
        self.label_40.setObjectName("label_40")
        self.gridLayout_18.addWidget(self.label_40, 2, 2, 1, 1)
        self._ToolSpinTmin = QtWidgets.QDoubleSpinBox(self._spin_page)
        self._ToolSpinTmin.setDecimals(1)
        self._ToolSpinTmin.setMaximum(10000.0)
        self._ToolSpinTmin.setProperty("value", 500.0)
        self._ToolSpinTmin.setObjectName("_ToolSpinTmin")
        self.gridLayout_18.addWidget(self._ToolSpinTmin, 1, 3, 1, 1)
        self.label_37 = QtWidgets.QLabel(self._spin_page)
        self.label_37.setObjectName("label_37")
        self.gridLayout_18.addWidget(self.label_37, 1, 6, 1, 1)
        self._ToolSpinRemOnly = QtWidgets.QCheckBox(self._spin_page)
        self._ToolSpinRemOnly.setObjectName("_ToolSpinRemOnly")
        self.gridLayout_18.addWidget(self._ToolSpinRemOnly, 3, 2, 1, 5)
        self._ToolSpinFmin = QtWidgets.QDoubleSpinBox(self._spin_page)
        self._ToolSpinFmin.setDecimals(1)
        self._ToolSpinFmin.setMaximum(200.0)
        self._ToolSpinFmin.setProperty("value", 12.0)
        self._ToolSpinFmin.setObjectName("_ToolSpinFmin")
        self.gridLayout_18.addWidget(self._ToolSpinFmin, 0, 3, 1, 1)
        self.line_5 = QtWidgets.QFrame(self._spin_page)
        self.line_5.setMinimumSize(QtCore.QSize(10, 0))
        self.line_5.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_5.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_5.setObjectName("line_5")
        self.gridLayout_18.addWidget(self.line_5, 0, 1, 4, 1)
        self.label_30 = QtWidgets.QLabel(self._spin_page)
        self.label_30.setObjectName("label_30")
        self.gridLayout_18.addWidget(self.label_30, 1, 4, 1, 1)
        self.label_22 = QtWidgets.QLabel(self._spin_page)
        self.label_22.setObjectName("label_22")
        self.gridLayout_18.addWidget(self.label_22, 1, 2, 1, 1)
        self.label_19 = QtWidgets.QLabel(self._spin_page)
        self.label_19.setObjectName("label_19")
        self.gridLayout_18.addWidget(self.label_19, 0, 2, 1, 1)
        self._ToolSpinFmax = QtWidgets.QDoubleSpinBox(self._spin_page)
        self._ToolSpinFmax.setDecimals(1)
        self._ToolSpinFmax.setMaximum(200.0)
        self._ToolSpinFmax.setProperty("value", 14.0)
        self._ToolSpinFmax.setObjectName("_ToolSpinFmax")
        self.gridLayout_18.addWidget(self._ToolSpinFmax, 0, 5, 1, 1)
        self.label_21 = QtWidgets.QLabel(self._spin_page)
        self.label_21.setObjectName("label_21")
        self.gridLayout_18.addWidget(self.label_21, 0, 6, 1, 1)
        self.label_52 = QtWidgets.QLabel(self._spin_page)
        font = QtGui.QFont()
        font.setItalic(True)
        font.setKerning(True)
        font.setStyleStrategy(QtGui.QFont.PreferDefault)
        self.label_52.setFont(font)
        self.label_52.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.label_52.setObjectName("label_52")
        self.gridLayout_18.addWidget(self.label_52, 0, 0, 4, 1)
        self._ToolSpinTmax = QtWidgets.QDoubleSpinBox(self._spin_page)
        self._ToolSpinTmax.setDecimals(1)
        self._ToolSpinTmax.setMaximum(10000.0)
        self._ToolSpinTmax.setProperty("value", 2000.0)
        self._ToolSpinTmax.setObjectName("_ToolSpinTmax")
        self.gridLayout_18.addWidget(self._ToolSpinTmax, 1, 5, 1, 1)
        self.label_20 = QtWidgets.QLabel(self._spin_page)
        self.label_20.setObjectName("label_20")
        self.gridLayout_18.addWidget(self.label_20, 0, 4, 1, 1)
        self._ToolSpinTh = QtWidgets.QDoubleSpinBox(self._spin_page)
        self._ToolSpinTh.setDecimals(1)
        self._ToolSpinTh.setProperty("value", 2.0)
        self._ToolSpinTh.setObjectName("_ToolSpinTh")
        self.gridLayout_18.addWidget(self._ToolSpinTh, 2, 3, 1, 2)
        self.verticalLayout_19.addLayout(self.gridLayout_18)
        spacerItem37 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_19.addItem(spacerItem37)
        self._stacked_detections.addWidget(self._spin_page)
        self._rem_page = QtWidgets.QWidget()
        self._rem_page.setObjectName("_rem_page")
        self.verticalLayout_20 = QtWidgets.QVBoxLayout(self._rem_page)
        self.verticalLayout_20.setObjectName("verticalLayout_20")
        self.gridLayout_17 = QtWidgets.QGridLayout()
        self.gridLayout_17.setContentsMargins(-1, 0, -1, -1)
        self.gridLayout_17.setObjectName("gridLayout_17")
        self._ToolRemTh = QtWidgets.QDoubleSpinBox(self._rem_page)
        self._ToolRemTh.setDecimals(1)
        self._ToolRemTh.setProperty("value", 3.0)
        self._ToolRemTh.setObjectName("_ToolRemTh")
        self.gridLayout_17.addWidget(self._ToolRemTh, 0, 3, 1, 1)
        self.label_38 = QtWidgets.QLabel(self._rem_page)
        self.label_38.setObjectName("label_38")
        self.gridLayout_17.addWidget(self.label_38, 0, 2, 1, 1)
        self._ToolRemOnly = QtWidgets.QCheckBox(self._rem_page)
        self._ToolRemOnly.setObjectName("_ToolRemOnly")
        self.gridLayout_17.addWidget(self._ToolRemOnly, 1, 2, 1, 4)
        self.line_2 = QtWidgets.QFrame(self._rem_page)
        self.line_2.setMinimumSize(QtCore.QSize(10, 0))
        self.line_2.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_2.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_2.setObjectName("line_2")
        self.gridLayout_17.addWidget(self.line_2, 0, 1, 2, 1)
        self.label_51 = QtWidgets.QLabel(self._rem_page)
        font = QtGui.QFont()
        font.setItalic(True)
        font.setKerning(True)
        font.setStyleStrategy(QtGui.QFont.PreferDefault)
        self.label_51.setFont(font)
        self.label_51.setObjectName("label_51")
        self.gridLayout_17.addWidget(self.label_51, 0, 0, 2, 1)
        spacerItem38 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_17.addItem(spacerItem38, 0, 4, 1, 1)
        self.verticalLayout_20.addLayout(self.gridLayout_17)
        spacerItem39 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_20.addItem(spacerItem39)
        self._stacked_detections.addWidget(self._rem_page)
        self._kcomp_page = QtWidgets.QWidget()
        self._kcomp_page.setObjectName("_kcomp_page")
        self.verticalLayout_23 = QtWidgets.QVBoxLayout(self._kcomp_page)
        self.verticalLayout_23.setObjectName("verticalLayout_23")
        self.gridLayout_8 = QtWidgets.QGridLayout()
        self.gridLayout_8.setContentsMargins(-1, 0, -1, -1)
        self.gridLayout_8.setVerticalSpacing(9)
        self.gridLayout_8.setObjectName("gridLayout_8")
        self.widget_8 = QtWidgets.QWidget(self._kcomp_page)
        self.widget_8.setMinimumSize(QtCore.QSize(0, 0))
        self.widget_8.setObjectName("widget_8")
        self.horizontalLayout_15 = QtWidgets.QHBoxLayout(self.widget_8)
        self.horizontalLayout_15.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_15.setSpacing(0)
        self.horizontalLayout_15.setObjectName("horizontalLayout_15")
        self.label_64 = QtWidgets.QLabel(self.widget_8)
        self.label_64.setObjectName("label_64")
        self.horizontalLayout_15.addWidget(self.label_64)
        self._ToolKCMinAmp = QtWidgets.QDoubleSpinBox(self.widget_8)
        self._ToolKCMinAmp.setDecimals(1)
        self._ToolKCMinAmp.setMinimum(10.0)
        self._ToolKCMinAmp.setMaximum(500.0)
        self._ToolKCMinAmp.setSingleStep(10.0)
        self._ToolKCMinAmp.setProperty("value", 80.0)
        self._ToolKCMinAmp.setObjectName("_ToolKCMinAmp")
        self.horizontalLayout_15.addWidget(self._ToolKCMinAmp)
        self._ToolKCMaxAmp = QtWidgets.QDoubleSpinBox(self.widget_8)
        self._ToolKCMaxAmp.setDecimals(1)
        self._ToolKCMaxAmp.setMinimum(110.0)
        self._ToolKCMaxAmp.setMaximum(1000.0)
        self._ToolKCMaxAmp.setSingleStep(10.0)
        self._ToolKCMaxAmp.setProperty("value", 600.0)
        self._ToolKCMaxAmp.setObjectName("_ToolKCMaxAmp")
        self.horizontalLayout_15.addWidget(self._ToolKCMaxAmp)
        self.gridLayout_8.addWidget(self.widget_8, 4, 2, 1, 4)
        self.label_57 = QtWidgets.QLabel(self._kcomp_page)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_57.sizePolicy().hasHeightForWidth())
        self.label_57.setSizePolicy(sizePolicy)
        self.label_57.setObjectName("label_57")
        self.gridLayout_8.addWidget(self.label_57, 0, 2, 2, 2)
        self.kc_label = QtWidgets.QLabel(self._kcomp_page)
        font = QtGui.QFont()
        font.setItalic(True)
        font.setKerning(True)
        font.setStyleStrategy(QtGui.QFont.PreferDefault)
        self.kc_label.setFont(font)
        self.kc_label.setObjectName("kc_label")
        self.gridLayout_8.addWidget(self.kc_label, 0, 0, 6, 1)
        self._ToolKCNremOnly = QtWidgets.QCheckBox(self._kcomp_page)
        self._ToolKCNremOnly.setObjectName("_ToolKCNremOnly")
        self.gridLayout_8.addWidget(self._ToolKCNremOnly, 5, 2, 1, 4)
        self._ToolKCProbTh = QtWidgets.QDoubleSpinBox(self._kcomp_page)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self._ToolKCProbTh.sizePolicy().hasHeightForWidth())
        self._ToolKCProbTh.setSizePolicy(sizePolicy)
        self._ToolKCProbTh.setMaximum(1.0)
        self._ToolKCProbTh.setSingleStep(0.1)
        self._ToolKCProbTh.setProperty("value", 0.7)
        self._ToolKCProbTh.setObjectName("_ToolKCProbTh")
        self.gridLayout_8.addWidget(self._ToolKCProbTh, 0, 4, 2, 2)
        self.line_19 = QtWidgets.QFrame(self._kcomp_page)
        self.line_19.setMinimumSize(QtCore.QSize(10, 0))
        self.line_19.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_19.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_19.setObjectName("line_19")
        self.gridLayout_8.addWidget(self.line_19, 0, 1, 6, 1)
        self.widget_7 = QtWidgets.QWidget(self._kcomp_page)
        self.widget_7.setMinimumSize(QtCore.QSize(0, 0))
        self.widget_7.setObjectName("widget_7")
        self.horizontalLayout_14 = QtWidgets.QHBoxLayout(self.widget_7)
        self.horizontalLayout_14.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_14.setSpacing(0)
        self.horizontalLayout_14.setObjectName("horizontalLayout_14")
        self.label_62 = QtWidgets.QLabel(self.widget_7)
        self.label_62.setToolTip("")
        self.label_62.setObjectName("label_62")
        self.horizontalLayout_14.addWidget(self.label_62)
        self._ToolKCMinDur = QtWidgets.QDoubleSpinBox(self.widget_7)
        self._ToolKCMinDur.setDecimals(1)
        self._ToolKCMinDur.setMaximum(1000.0)
        self._ToolKCMinDur.setSingleStep(50.0)
        self._ToolKCMinDur.setProperty("value", 400.0)
        self._ToolKCMinDur.setObjectName("_ToolKCMinDur")
        self.horizontalLayout_14.addWidget(self._ToolKCMinDur)
        self._ToolKCMaxDur = QtWidgets.QDoubleSpinBox(self.widget_7)
        self._ToolKCMaxDur.setDecimals(1)
        self._ToolKCMaxDur.setMinimum(1000.0)
        self._ToolKCMaxDur.setMaximum(10000.0)
        self._ToolKCMaxDur.setSingleStep(100.0)
        self._ToolKCMaxDur.setProperty("value", 3000.0)
        self._ToolKCMaxDur.setObjectName("_ToolKCMaxDur")
        self.horizontalLayout_14.addWidget(self._ToolKCMaxDur)
        self.gridLayout_8.addWidget(self.widget_7, 3, 2, 1, 4)
        self._ToolKCAmpTh = QtWidgets.QDoubleSpinBox(self._kcomp_page)
        self._ToolKCAmpTh.setMaximum(10.0)
        self._ToolKCAmpTh.setSingleStep(0.5)
        self._ToolKCAmpTh.setProperty("value", 1.0)
        self._ToolKCAmpTh.setObjectName("_ToolKCAmpTh")
        self.gridLayout_8.addWidget(self._ToolKCAmpTh, 2, 4, 1, 2)
        self.label_71 = QtWidgets.QLabel(self._kcomp_page)
        self.label_71.setObjectName("label_71")
        self.gridLayout_8.addWidget(self.label_71, 2, 2, 1, 2)
        self.verticalLayout_23.addLayout(self.gridLayout_8)
        spacerItem40 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_23.addItem(spacerItem40)
        self._stacked_detections.addWidget(self._kcomp_page)
        self._sw_page = QtWidgets.QWidget()
        self._sw_page.setObjectName("_sw_page")
        self.verticalLayout_24 = QtWidgets.QVBoxLayout(self._sw_page)
        self.verticalLayout_24.setObjectName("verticalLayout_24")
        self.gridLayout_9 = QtWidgets.QGridLayout()
        self.gridLayout_9.setObjectName("gridLayout_9")
        self.label_53 = QtWidgets.QLabel(self._sw_page)
        font = QtGui.QFont()
        font.setItalic(True)
        font.setKerning(True)
        font.setStyleStrategy(QtGui.QFont.PreferDefault)
        self.label_53.setFont(font)
        self.label_53.setObjectName("label_53")
        self.gridLayout_9.addWidget(self.label_53, 0, 0, 2, 1)
        self._ToolWaveTh = QtWidgets.QDoubleSpinBox(self._sw_page)
        self._ToolWaveTh.setMaximum(1.0)
        self._ToolWaveTh.setSingleStep(0.05)
        self._ToolWaveTh.setProperty("value", 0.75)
        self._ToolWaveTh.setObjectName("_ToolWaveTh")
        self.gridLayout_9.addWidget(self._ToolWaveTh, 0, 3, 2, 1)
        self.line_7 = QtWidgets.QFrame(self._sw_page)
        self.line_7.setMinimumSize(QtCore.QSize(10, 0))
        self.line_7.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_7.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_7.setObjectName("line_7")
        self.gridLayout_9.addWidget(self.line_7, 0, 1, 2, 1)
        self.label_46 = QtWidgets.QLabel(self._sw_page)
        self.label_46.setObjectName("label_46")
        self.gridLayout_9.addWidget(self.label_46, 0, 2, 2, 1)
        spacerItem41 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_9.addItem(spacerItem41, 0, 4, 2, 1)
        self.verticalLayout_24.addLayout(self.gridLayout_9)
        spacerItem42 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_24.addItem(spacerItem42)
        self._stacked_detections.addWidget(self._sw_page)
        self._mt_page = QtWidgets.QWidget()
        self._mt_page.setObjectName("_mt_page")
        self.verticalLayout_27 = QtWidgets.QVBoxLayout(self._mt_page)
        self.verticalLayout_27.setObjectName("verticalLayout_27")
        self.gridLayout_29 = QtWidgets.QGridLayout()
        self.gridLayout_29.setContentsMargins(-1, 0, -1, -1)
        self.gridLayout_29.setObjectName("gridLayout_29")
        self._ToolMTTh = QtWidgets.QDoubleSpinBox(self._mt_page)
        self._ToolMTTh.setDecimals(1)
        self._ToolMTTh.setMaximum(20.0)
        self._ToolMTTh.setProperty("value", 3.0)
        self._ToolMTTh.setObjectName("_ToolMTTh")
        self.gridLayout_29.addWidget(self._ToolMTTh, 0, 3, 1, 1)
        self.label_93 = QtWidgets.QLabel(self._mt_page)
        self.label_93.setObjectName("label_93")
        self.gridLayout_29.addWidget(self.label_93, 0, 2, 1, 1)
        self._ToolMTOnly = QtWidgets.QCheckBox(self._mt_page)
        self._ToolMTOnly.setObjectName("_ToolMTOnly")
        self.gridLayout_29.addWidget(self._ToolMTOnly, 1, 2, 1, 4)
        self.line_37 = QtWidgets.QFrame(self._mt_page)
        self.line_37.setMinimumSize(QtCore.QSize(10, 0))
        self.line_37.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_37.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_37.setObjectName("line_37")
        self.gridLayout_29.addWidget(self.line_37, 0, 1, 2, 1)
        self.label_94 = QtWidgets.QLabel(self._mt_page)
        font = QtGui.QFont()
        font.setItalic(True)
        font.setKerning(True)
        font.setStyleStrategy(QtGui.QFont.PreferDefault)
        self.label_94.setFont(font)
        self.label_94.setObjectName("label_94")
        self.gridLayout_29.addWidget(self.label_94, 0, 0, 2, 1)
        spacerItem43 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_29.addItem(spacerItem43, 0, 4, 1, 1)
        self.verticalLayout_27.addLayout(self.gridLayout_29)
        spacerItem44 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_27.addItem(spacerItem44)
        self._stacked_detections.addWidget(self._mt_page)
        self._peak_page = QtWidgets.QWidget()
        self._peak_page.setObjectName("_peak_page")
        self.verticalLayout_43 = QtWidgets.QVBoxLayout(self._peak_page)
        self.verticalLayout_43.setObjectName("verticalLayout_43")
        self.gridLayout_11 = QtWidgets.QGridLayout()
        self.gridLayout_11.setContentsMargins(-1, 0, -1, -1)
        self.gridLayout_11.setObjectName("gridLayout_11")
        self.label_26 = QtWidgets.QLabel(self._peak_page)
        self.label_26.setObjectName("label_26")
        self.gridLayout_11.addWidget(self.label_26, 0, 2, 1, 1)
        self._ToolPeakLook = QtWidgets.QDoubleSpinBox(self._peak_page)
        self._ToolPeakLook.setDecimals(1)
        self._ToolPeakLook.setProperty("value", 0.5)
        self._ToolPeakLook.setObjectName("_ToolPeakLook")
        self.gridLayout_11.addWidget(self._ToolPeakLook, 0, 3, 1, 1)
        self.label_28 = QtWidgets.QLabel(self._peak_page)
        self.label_28.setObjectName("label_28")
        self.gridLayout_11.addWidget(self.label_28, 1, 2, 1, 1)
        self.label_27 = QtWidgets.QLabel(self._peak_page)
        self.label_27.setObjectName("label_27")
        self.gridLayout_11.addWidget(self.label_27, 0, 4, 1, 1)
        self._ToolPeakMinMax = QtWidgets.QComboBox(self._peak_page)
        self._ToolPeakMinMax.setObjectName("_ToolPeakMinMax")
        self._ToolPeakMinMax.addItem("")
        self._ToolPeakMinMax.addItem("")
        self._ToolPeakMinMax.addItem("")
        self.gridLayout_11.addWidget(self._ToolPeakMinMax, 1, 3, 1, 2)
        spacerItem45 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_11.addItem(spacerItem45, 0, 5, 1, 1)
        self.label_50 = QtWidgets.QLabel(self._peak_page)
        font = QtGui.QFont()
        font.setItalic(True)
        font.setKerning(True)
        font.setStyleStrategy(QtGui.QFont.PreferDefault)
        self.label_50.setFont(font)
        self.label_50.setObjectName("label_50")
        self.gridLayout_11.addWidget(self.label_50, 0, 0, 2, 1)
        self.line = QtWidgets.QFrame(self._peak_page)
        self.line.setMinimumSize(QtCore.QSize(10, 0))
        self.line.setFrameShape(QtWidgets.QFrame.VLine)
        self.line.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line.setObjectName("line")
        self.gridLayout_11.addWidget(self.line, 0, 1, 2, 1)
        self.verticalLayout_43.addLayout(self.gridLayout_11)
        spacerItem46 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_43.addItem(spacerItem46)
        self._stacked_detections.addWidget(self._peak_page)
        self.verticalLayout_26.addWidget(self._stacked_detections)
        self.verticalLayout_38.addWidget(self.groupBox_2)
        self._ToolDetectTable = QtWidgets.QTableWidget(self.q_DetectSettings)
        self._ToolDetectTable.setMaximumSize(QtCore.QSize(16777215, 100))
        self._ToolDetectTable.setObjectName("_ToolDetectTable")
        self._ToolDetectTable.setColumnCount(2)
        self._ToolDetectTable.setRowCount(0)
        item = QtWidgets.QTableWidgetItem()
        self._ToolDetectTable.setHorizontalHeaderItem(0, item)
        item = QtWidgets.QTableWidgetItem()
        self._ToolDetectTable.setHorizontalHeaderItem(1, item)
        self._ToolDetectTable.horizontalHeader().setStretchLastSection(True)
        self.verticalLayout_38.addWidget(self._ToolDetectTable)
        self.horizontalLayout_8 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_8.setContentsMargins(-1, 0, -1, -1)
        self.horizontalLayout_8.setObjectName("horizontalLayout_8")
        spacerItem47 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_8.addItem(spacerItem47)
        self._ToolDetectApply = QtWidgets.QPushButton(self.q_DetectSettings)
        self._ToolDetectApply.setObjectName("_ToolDetectApply")
        self.horizontalLayout_8.addWidget(self._ToolDetectApply)
        spacerItem48 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_8.addItem(spacerItem48)
        self.verticalLayout_38.addLayout(self.horizontalLayout_8)
        spacerItem49 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_38.addItem(spacerItem49)
        self._ToolDetectProgress = QtWidgets.QProgressBar(self.q_DetectSettings)
        self._ToolDetectProgress.setProperty("value", 0)
        self._ToolDetectProgress.setInvertedAppearance(False)
        self._ToolDetectProgress.setObjectName("_ToolDetectProgress")
        self.verticalLayout_38.addWidget(self._ToolDetectProgress)
        self._DetectionTab.addTab(self.q_DetectSettings, "")
        self.q_DetectLoc = QtWidgets.QWidget()
        self.q_DetectLoc.setObjectName("q_DetectLoc")
        self.verticalLayout_39 = QtWidgets.QVBoxLayout(self.q_DetectLoc)
        self.verticalLayout_39.setObjectName("verticalLayout_39")
        self.gridLayout_23 = QtWidgets.QGridLayout()
        self.gridLayout_23.setContentsMargins(9, 0, -1, 0)
        self.gridLayout_23.setSpacing(3)
        self.gridLayout_23.setObjectName("gridLayout_23")
        self.label_72 = QtWidgets.QLabel(self.q_DetectLoc)
        font = QtGui.QFont()
        font.setItalic(True)
        font.setKerning(True)
        font.setStyleStrategy(QtGui.QFont.PreferDefault)
        self.label_72.setFont(font)
        self.label_72.setObjectName("label_72")
        self.gridLayout_23.addWidget(self.label_72, 0, 0, 3, 1)
        self.line_28 = QtWidgets.QFrame(self.q_DetectLoc)
        self.line_28.setMinimumSize(QtCore.QSize(10, 0))
        self.line_28.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_28.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_28.setObjectName("line_28")
        self.gridLayout_23.addWidget(self.line_28, 0, 1, 3, 1)
        self.widget_11 = QtWidgets.QWidget(self.q_DetectLoc)
        self.widget_11.setObjectName("widget_11")
        self.horizontalLayout_19 = QtWidgets.QHBoxLayout(self.widget_11)
        self.horizontalLayout_19.setContentsMargins(-1, 3, -1, 3)
        self.horizontalLayout_19.setObjectName("horizontalLayout_19")
        self._DetectViz = QtWidgets.QCheckBox(self.widget_11)
        self._DetectViz.setChecked(True)
        self._DetectViz.setTristate(False)
        self._DetectViz.setObjectName("_DetectViz")
        self.horizontalLayout_19.addWidget(self._DetectViz)
        self._DetectRm = QtWidgets.QPushButton(self.widget_11)
        self._DetectRm.setObjectName("_DetectRm")
        self.horizontalLayout_19.addWidget(self._DetectRm)
        self.gridLayout_23.addWidget(self.widget_11, 2, 2, 1, 2)
        self.widget_12 = QtWidgets.QWidget(self.q_DetectLoc)
        self.widget_12.setMinimumSize(QtCore.QSize(0, 0))
        self.widget_12.setObjectName("widget_12")
        self.horizontalLayout_10 = QtWidgets.QHBoxLayout(self.widget_12)
        self.horizontalLayout_10.setContentsMargins(-1, 0, -1, 0)
        self.horizontalLayout_10.setObjectName("horizontalLayout_10")
        self.gridLayout_23.addWidget(self.widget_12, 3, 2, 1, 2)
        self.line_30 = QtWidgets.QFrame(self.q_DetectLoc)
        self.line_30.setMinimumSize(QtCore.QSize(10, 0))
        self.line_30.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_30.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_30.setObjectName("line_30")
        self.gridLayout_23.addWidget(self.line_30, 3, 1, 1, 1)
        self._DetectChanSw = QtWidgets.QComboBox(self.q_DetectLoc)
        self._DetectChanSw.setObjectName("_DetectChanSw")
        self.gridLayout_23.addWidget(self._DetectChanSw, 1, 2, 1, 2)
        self.verticalLayout_39.addLayout(self.gridLayout_23)
        self._DetectLocations = QtWidgets.QTableWidget(self.q_DetectLoc)
        self._DetectLocations.setDragDropMode(QtWidgets.QAbstractItemView.InternalMove)
        self._DetectLocations.setAlternatingRowColors(True)
        self._DetectLocations.setObjectName("_DetectLocations")
        self._DetectLocations.setColumnCount(4)
        self._DetectLocations.setRowCount(0)
        item = QtWidgets.QTableWidgetItem()
        self._DetectLocations.setHorizontalHeaderItem(0, item)
        item = QtWidgets.QTableWidgetItem()
        self._DetectLocations.setHorizontalHeaderItem(1, item)
        item = QtWidgets.QTableWidgetItem()
        self._DetectLocations.setHorizontalHeaderItem(2, item)
        item = QtWidgets.QTableWidgetItem()
        self._DetectLocations.setHorizontalHeaderItem(3, item)
        self._DetectLocations.horizontalHeader().setStretchLastSection(True)
        self.verticalLayout_39.addWidget(self._DetectLocations)
        self.horizontalLayout_20 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_20.setContentsMargins(-1, 0, -1, -1)
        self.horizontalLayout_20.setObjectName("horizontalLayout_20")
        spacerItem50 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_20.addItem(spacerItem50)
        self._DetecRmEvent = QtWidgets.QPushButton(self.q_DetectLoc)
        self._DetecRmEvent.setObjectName("_DetecRmEvent")
        self.horizontalLayout_20.addWidget(self._DetecRmEvent)
        spacerItem51 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_20.addItem(spacerItem51)
        self.verticalLayout_39.addLayout(self.horizontalLayout_20)
        self._DetectionTab.addTab(self.q_DetectLoc, "")
        self.verticalLayout_22.addWidget(self._DetectionTab)
        self.QuickSettings.addTab(self.q_Detection, "")
        self.tab = QtWidgets.QWidget()
        self.tab.setObjectName("tab")
        self.verticalLayout_11 = QtWidgets.QVBoxLayout(self.tab)
        self.verticalLayout_11.setObjectName("verticalLayout_11")
        self._AnnotateTable = QtWidgets.QTableWidget(self.tab)
        self._AnnotateTable.setDragEnabled(True)
        self._AnnotateTable.setAlternatingRowColors(True)
        self._AnnotateTable.setObjectName("_AnnotateTable")
        self._AnnotateTable.setColumnCount(3)
        self._AnnotateTable.setRowCount(0)
        item = QtWidgets.QTableWidgetItem()
        self._AnnotateTable.setHorizontalHeaderItem(0, item)
        item = QtWidgets.QTableWidgetItem()
        self._AnnotateTable.setHorizontalHeaderItem(1, item)
        item = QtWidgets.QTableWidgetItem()
        self._AnnotateTable.setHorizontalHeaderItem(2, item)
        self._AnnotateTable.horizontalHeader().setStretchLastSection(True)
        self.verticalLayout_11.addWidget(self._AnnotateTable)
        self.horizontalLayout_21 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_21.setContentsMargins(-1, 0, -1, -1)
        self.horizontalLayout_21.setObjectName("horizontalLayout_21")
        self._AnnotateAdd = QtWidgets.QPushButton(self.tab)
        self._AnnotateAdd.setObjectName("_AnnotateAdd")
        self.horizontalLayout_21.addWidget(self._AnnotateAdd)
        self._AnnotateRm = QtWidgets.QPushButton(self.tab)
        self._AnnotateRm.setObjectName("_AnnotateRm")
        self.horizontalLayout_21.addWidget(self._AnnotateRm)
        self.verticalLayout_11.addLayout(self.horizontalLayout_21)
        self.QuickSettings.addTab(self.tab, "")
        self.verticalLayout_4.addWidget(self.QuickSettings)
        self.layoutWidget = QtWidgets.QWidget(self.splitter)
        self.layoutWidget.setObjectName("layoutWidget")
        self.gridLayout_21 = QtWidgets.QGridLayout(self.layoutWidget)
        self.gridLayout_21.setContentsMargins(0, 0, 0, 0)
        self.gridLayout_21.setObjectName("gridLayout_21")
        self._topoW = QtWidgets.QWidget(self.layoutWidget)
        self._topoW.setMinimumSize(QtCore.QSize(250, 0))
        self._topoW.setMaximumSize(QtCore.QSize(300, 16777215))
        self._topoW.setObjectName("_topoW")
        self.verticalLayout_31 = QtWidgets.QVBoxLayout(self._topoW)
        self.verticalLayout_31.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_31.setSpacing(0)
        self.verticalLayout_31.setObjectName("verticalLayout_31")
        self._topoLayout = QtWidgets.QVBoxLayout()
        self._topoLayout.setContentsMargins(-1, 0, -1, -1)
        self._topoLayout.setObjectName("_topoLayout")
        self._topoTitle = QtWidgets.QLabel(self._topoW)
        self._topoTitle.setMaximumSize(QtCore.QSize(16777215, 40))
        font = QtGui.QFont()
        font.setPointSize(12)
        font.setBold(True)
        font.setWeight(75)
        font.setKerning(True)
        font.setStyleStrategy(QtGui.QFont.PreferDefault)
        self._topoTitle.setFont(font)
        self._topoTitle.setAlignment(QtCore.Qt.AlignCenter)
        self._topoTitle.setObjectName("_topoTitle")
        self._topoLayout.addWidget(self._topoTitle)
        self.verticalLayout_31.addLayout(self._topoLayout)
        self.gridLayout_21.addWidget(self._topoW, 0, 1, 1, 1)
        spacerItem52 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_21.addItem(spacerItem52, 0, 0, 1, 1)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setContentsMargins(20, 0, 20, 0)
        self.horizontalLayout_3.setSpacing(6)
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        spacerItem53 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_3.addItem(spacerItem53)
        self._slFrame = QtWidgets.QFrame(self.layoutWidget)
        self._slFrame.setMinimumSize(QtCore.QSize(0, 0))
        self._slFrame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self._slFrame.setFrameShadow(QtWidgets.QFrame.Raised)
        self._slFrame.setObjectName("_slFrame")
        self.verticalLayout_15 = QtWidgets.QVBoxLayout(self._slFrame)
        self.verticalLayout_15.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_15.setSpacing(0)
        self.verticalLayout_15.setObjectName("verticalLayout_15")
        self.gridLayout_7 = QtWidgets.QGridLayout()
        self.gridLayout_7.setContentsMargins(-1, 0, -1, -1)
        self.gridLayout_7.setHorizontalSpacing(7)
        self.gridLayout_7.setVerticalSpacing(9)
        self.gridLayout_7.setObjectName("gridLayout_7")
        self._slRules = QtWidgets.QComboBox(self._slFrame)
        self._slRules.setObjectName("_slRules")
        self._slRules.addItem("")
        self._slRules.addItem("")
        self._slRules.addItem("")
        self.gridLayout_7.addWidget(self._slRules, 2, 14, 1, 1)
        self._SlGoto = QtWidgets.QDoubleSpinBox(self._slFrame)
        self._SlGoto.setDecimals(1)
        self._SlGoto.setObjectName("_SlGoto")
        self.gridLayout_7.addWidget(self._SlGoto, 2, 2, 1, 1)
        self.horizontalLayout_22 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_22.setContentsMargins(-1, 6, -1, -1)
        self.horizontalLayout_22.setObjectName("horizontalLayout_22")
        self._txtCursor = QtWidgets.QLabel(self._slFrame)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        font.setKerning(True)
        font.setStyleStrategy(QtGui.QFont.PreferDefault)
        self._txtCursor.setFont(font)
        self._txtCursor.setObjectName("_txtCursor")
        self.horizontalLayout_22.addWidget(self._txtCursor)
        spacerItem54 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_22.addItem(spacerItem54)
        self._SlText = QtWidgets.QLabel(self._slFrame)
        self._SlText.setAlignment(QtCore.Qt.AlignCenter)
        self._SlText.setObjectName("_SlText")
        self.horizontalLayout_22.addWidget(self._SlText)
        spacerItem55 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_22.addItem(spacerItem55)
        self._AnnotateRun = QtWidgets.QPushButton(self._slFrame)
        self._AnnotateRun.setObjectName("_AnnotateRun")
        self.horizontalLayout_22.addWidget(self._AnnotateRun)
        spacerItem56 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_22.addItem(spacerItem56)
        self.gridLayout_7.addLayout(self.horizontalLayout_22, 0, 1, 1, 21)
        self.label_2 = QtWidgets.QLabel(self._slFrame)
        self.label_2.setObjectName("label_2")
        self.gridLayout_7.addWidget(self.label_2, 2, 17, 1, 1)
        self._slMagnify = QtWidgets.QCheckBox(self._slFrame)
        self._slMagnify.setObjectName("_slMagnify")
        self.gridLayout_7.addWidget(self._slMagnify, 2, 21, 1, 1)
        self._SigSlStep = QtWidgets.QDoubleSpinBox(self._slFrame)
        self._SigSlStep.setDecimals(1)
        self._SigSlStep.setMinimum(0.1)
        self._SigSlStep.setProperty("value", 30.0)
        self._SigSlStep.setObjectName("_SigSlStep")
        self.gridLayout_7.addWidget(self._SigSlStep, 2, 10, 1, 1)
        spacerItem57 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_7.addItem(spacerItem57, 2, 8, 1, 1)
        spacerItem58 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Maximum, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_7.addItem(spacerItem58, 2, 4, 1, 1)
        self._SigWin = QtWidgets.QDoubleSpinBox(self._slFrame)
        self._SigWin.setDecimals(1)
        self._SigWin.setMaximum(1000.0)
        self._SigWin.setProperty("value", 30.0)
        self._SigWin.setObjectName("_SigWin")
        self.gridLayout_7.addWidget(self._SigWin, 2, 6, 1, 1)
        self.label_12 = QtWidgets.QLabel(self._slFrame)
        self.label_12.setObjectName("label_12")
        self.gridLayout_7.addWidget(self.label_12, 2, 3, 1, 1)
        self.label = QtWidgets.QLabel(self._slFrame)
        self.label.setObjectName("label")
        self.gridLayout_7.addWidget(self.label, 2, 1, 1, 1)
        self.label_3 = QtWidgets.QLabel(self._slFrame)
        self.label_3.setObjectName("label_3")
        self.gridLayout_7.addWidget(self.label_3, 2, 5, 1, 1)
        self.label_5 = QtWidgets.QLabel(self._slFrame)
        self.label_5.setObjectName("label_5")
        self.gridLayout_7.addWidget(self.label_5, 2, 9, 1, 1)
        self._SlVal = QtWidgets.QSlider(self._slFrame)
        self._SlVal.setOrientation(QtCore.Qt.Horizontal)
        self._SlVal.setTickPosition(QtWidgets.QSlider.NoTicks)
        self._SlVal.setTickInterval(10)
        self._SlVal.setObjectName("_SlVal")
        self.gridLayout_7.addWidget(self._SlVal, 1, 1, 1, 21)
        self._SignV = QtWidgets.QDoubleSpinBox(self._slFrame)
        self._SignV.setSingleStep(0.01)
        self._SignV.setProperty("value", 1.0)
        self._SignV.setObjectName("_SignV")
        self.gridLayout_7.addWidget(self._SignV, 2, 16, 1, 1)
        self._slAbsTime = QtWidgets.QCheckBox(self._slFrame)
        self._slAbsTime.setObjectName("_slAbsTime")
        self.gridLayout_7.addWidget(self._slAbsTime, 2, 20, 1, 1)
        spacerItem59 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_7.addItem(spacerItem59, 2, 15, 1, 1)
        self._slGrid = QtWidgets.QCheckBox(self._slFrame)
        self._slGrid.setChecked(False)
        self._slGrid.setObjectName("_slGrid")
        self.gridLayout_7.addWidget(self._slGrid, 2, 19, 1, 1)
        self.label_4 = QtWidgets.QLabel(self._slFrame)
        self.label_4.setObjectName("label_4")
        self.gridLayout_7.addWidget(self.label_4, 2, 7, 1, 1)
        spacerItem60 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_7.addItem(spacerItem60, 2, 12, 1, 1)
        self.label_31 = QtWidgets.QLabel(self._slFrame)
        self.label_31.setObjectName("label_31")
        self.gridLayout_7.addWidget(self.label_31, 2, 13, 1, 1)
        self.label_6 = QtWidgets.QLabel(self._slFrame)
        self.label_6.setObjectName("label_6")
        self.gridLayout_7.addWidget(self.label_6, 2, 11, 1, 1)
        self._slStageColors = QtWidgets.QCheckBox(self._slFrame)
        self._slStageColors.setObjectName("_slStageColors")
        self.gridLayout_7.addWidget(self._slStageColors, 2, 18, 1, 1)
        self.verticalLayout_15.addLayout(self.gridLayout_7)
        self.horizontalLayout_3.addWidget(self._slFrame)
        spacerItem61 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_3.addItem(spacerItem61)
        self.gridLayout_21.addLayout(self.horizontalLayout_3, 1, 0, 1, 2)
        self.horizontalLayout_2.addWidget(self.splitter)
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 1628, 24))
        self.menubar.setObjectName("menubar")
        self.menuFiles = QtWidgets.QMenu(self.menubar)
        self.menuFiles.setObjectName("menuFiles")
        self.menuSave = QtWidgets.QMenu(self.menuFiles)
        self.menuSave.setObjectName("menuSave")
        self.menuSaveHypnogram = QtWidgets.QMenu(self.menuSave)
        self.menuSaveHypnogram.setObjectName("menuSaveHypnogram")
        self.menuSaveDetections = QtWidgets.QMenu(self.menuSave)
        self.menuSaveDetections.setEnabled(False)
        self.menuSaveDetections.setObjectName("menuSaveDetections")
        self.menuLoad = QtWidgets.QMenu(self.menuFiles)
        self.menuLoad.setObjectName("menuLoad")
        self.menuLoadDetections = QtWidgets.QMenu(self.menuLoad)
        self.menuLoadDetections.setObjectName("menuLoadDetections")
        self.menuDisplay = QtWidgets.QMenu(self.menubar)
        self.menuDisplay.setObjectName("menuDisplay")
        MainWindow.setMenuBar(self.menubar)
        self.statusbar = QtWidgets.QStatusBar(MainWindow)
        self.statusbar.setObjectName("statusbar")
        MainWindow.setStatusBar(self.statusbar)
        self.actionSave = QtWidgets.QAction(MainWindow)
        self.actionSave.setObjectName("actionSave")
        self.actionLoad = QtWidgets.QAction(MainWindow)
        self.actionLoad.setObjectName("actionLoad")
        self.actionCortical_repartition = QtWidgets.QAction(MainWindow)
        self.actionCortical_repartition.setObjectName("actionCortical_repartition")
        self.actionCortical = QtWidgets.QAction(MainWindow)
        self.actionCortical.setObjectName("actionCortical")
        self.actionSagittal = QtWidgets.QAction(MainWindow)
        self.actionSagittal.setObjectName("actionSagittal")
        self.actionAxial = QtWidgets.QAction(MainWindow)
        self.actionAxial.setObjectName("actionAxial")
        self.actionCamera = QtWidgets.QAction(MainWindow)
        self.actionCamera.setObjectName("actionCamera")
        self.actionLeft = QtWidgets.QAction(MainWindow)
        self.actionLeft.setObjectName("actionLeft")
        self.actionRight = QtWidgets.QAction(MainWindow)
        self.actionRight.setObjectName("actionRight")
        self.menuDispSettings = QtWidgets.QAction(MainWindow)
        self.menuDispSettings.setCheckable(True)
        self.menuDispSettings.setChecked(False)
        self.menuDispSettings.setObjectName("menuDispSettings")
        self.actionClose = QtWidgets.QAction(MainWindow)
        self.actionClose.setObjectName("actionClose")
        self.actionProjection = QtWidgets.QAction(MainWindow)
        self.actionProjection.setObjectName("actionProjection")
        self.actionRepartition = QtWidgets.QAction(MainWindow)
        self.actionRepartition.setObjectName("actionRepartition")
        self.actionShortcuts = QtWidgets.QAction(MainWindow)
        self.actionShortcuts.setCheckable(True)
        self.actionShortcuts.setObjectName("actionShortcuts")
        self.actionUi_settings = QtWidgets.QAction(MainWindow)
        self.actionUi_settings.setCheckable(True)
        self.actionUi_settings.setChecked(False)
        self.actionUi_settings.setObjectName("actionUi_settings")
        self.actionNdPlt = QtWidgets.QAction(MainWindow)
        self.actionNdPlt.setCheckable(True)
        self.actionNdPlt.setObjectName("actionNdPlt")
        self.actionOnedPlt = QtWidgets.QAction(MainWindow)
        self.actionOnedPlt.setCheckable(True)
        self.actionOnedPlt.setObjectName("actionOnedPlt")
        self.actionImage = QtWidgets.QAction(MainWindow)
        self.actionImage.setCheckable(True)
        self.actionImage.setObjectName("actionImage")
        self.actionColormap = QtWidgets.QAction(MainWindow)
        self.actionColormap.setCheckable(True)
        self.actionColormap.setObjectName("actionColormap")
        self.menuShortcut = QtWidgets.QAction(MainWindow)
        self.menuShortcut.setObjectName("menuShortcut")
        self.menuDocumentation = QtWidgets.QAction(MainWindow)
        self.menuDocumentation.setObjectName("menuDocumentation")
        self.actionScreenshot = QtWidgets.QAction(MainWindow)
        self.actionScreenshot.setObjectName("actionScreenshot")
        self.actionSave_hypnogram = QtWidgets.QAction(MainWindow)
        self.actionSave_hypnogram.setObjectName("actionSave_hypnogram")
        self.actionSave_infos = QtWidgets.QAction(MainWindow)
        self.actionSave_infos.setObjectName("actionSave_infos")
        self.actionSave_scoring = QtWidgets.QAction(MainWindow)
        self.actionSave_scoring.setObjectName("actionSave_scoring")
        self.actionSave_detection = QtWidgets.QAction(MainWindow)
        self.actionSave_detection.setObjectName("actionSave_detection")
        self.actionSave_all = QtWidgets.QAction(MainWindow)
        self.actionSave_all.setObjectName("actionSave_all")
        self.menuExit = QtWidgets.QAction(MainWindow)
        self.menuExit.setObjectName("menuExit")
        self.actionLoad_hypnogram = QtWidgets.QAction(MainWindow)
        self.actionLoad_hypnogram.setObjectName("actionLoad_hypnogram")
        self.menuSaveInfoTable = QtWidgets.QAction(MainWindow)
        self.menuSaveInfoTable.setObjectName("menuSaveInfoTable")
        self.menuSaveScoringTable = QtWidgets.QAction(MainWindow)
        self.menuSaveScoringTable.setObjectName("menuSaveScoringTable")
        self.actionAll = QtWidgets.QAction(MainWindow)
        self.actionAll.setObjectName("actionAll")
        self.menuLoadHypno = QtWidgets.QAction(MainWindow)
        self.menuLoadHypno.setObjectName("menuLoadHypno")
        self.menuLoadData = QtWidgets.QAction(MainWindow)
        self.menuLoadData.setEnabled(False)
        self.menuLoadData.setObjectName("menuLoadData")
        self.actionHypnogram_figure = QtWidgets.QAction(MainWindow)
        self.actionHypnogram_figure.setObjectName("actionHypnogram_figure")
        self.menuLoadConfig = QtWidgets.QAction(MainWindow)
        self.menuLoadConfig.setObjectName("menuLoadConfig")
        self.menuSaveConfig = QtWidgets.QAction(MainWindow)
        self.menuSaveConfig.setObjectName("menuSaveConfig")
        self.menuDownload_pdf_doc = QtWidgets.QAction(MainWindow)
        self.menuDownload_pdf_doc.setObjectName("menuDownload_pdf_doc")
        self.menuSaveHypnogramFigure = QtWidgets.QAction(MainWindow)
        self.menuSaveHypnogramFigure.setObjectName("menuSaveHypnogramFigure")
        self.menuSaveHypnogramData = QtWidgets.QAction(MainWindow)
        self.menuSaveHypnogramData.setObjectName("menuSaveHypnogramData")
        self.menuSaveDetectAll = QtWidgets.QAction(MainWindow)
        self.menuSaveDetectAll.setObjectName("menuSaveDetectAll")
        self.menuSaveDetectSelected = QtWidgets.QAction(MainWindow)
        self.menuSaveDetectSelected.setObjectName("menuSaveDetectSelected")
        self.menuSaveScreenshotEntire = QtWidgets.QAction(MainWindow)
        self.menuSaveScreenshotEntire.setObjectName("menuSaveScreenshotEntire")
        self.menuSaveScreenshotSelected = QtWidgets.QAction(MainWindow)
        self.menuSaveScreenshotSelected.setEnabled(False)
        self.menuSaveScreenshotSelected.setObjectName("menuSaveScreenshotSelected")
        self.menuLoadDetectAll = QtWidgets.QAction(MainWindow)
        self.menuLoadDetectAll.setObjectName("menuLoadDetectAll")
        self.menuLoadDetectSelect = QtWidgets.QAction(MainWindow)
        self.menuLoadDetectSelect.setObjectName("menuLoadDetectSelect")
        self.menuDispSpec = QtWidgets.QAction(MainWindow)
        self.menuDispSpec.setCheckable(True)
        self.menuDispSpec.setChecked(True)
        self.menuDispSpec.setObjectName("menuDispSpec")
        self.menuDispHypno = QtWidgets.QAction(MainWindow)
        self.menuDispHypno.setCheckable(True)
        self.menuDispHypno.setChecked(True)
        self.menuDispHypno.setObjectName("menuDispHypno")
        self.menuDispNavbar = QtWidgets.QAction(MainWindow)
        self.menuDispNavbar.setCheckable(True)
        self.menuDispNavbar.setChecked(True)
        self.menuDispNavbar.setObjectName("menuDispNavbar")
        self.menuDispTimeax = QtWidgets.QAction(MainWindow)
        self.menuDispTimeax.setCheckable(True)
        self.menuDispTimeax.setChecked(True)
        self.menuDispTimeax.setObjectName("menuDispTimeax")
        self.menuDispTopo = QtWidgets.QAction(MainWindow)
        self.menuDispTopo.setCheckable(True)
        self.menuDispTopo.setObjectName("menuDispTopo")
        self.menuDispIndic = QtWidgets.QAction(MainWindow)
        self.menuDispIndic.setCheckable(True)
        self.menuDispIndic.setChecked(True)
        self.menuDispIndic.setObjectName("menuDispIndic")
        self.actionZoom_mode = QtWidgets.QAction(MainWindow)
        self.actionZoom_mode.setCheckable(True)
        self.actionZoom_mode.setObjectName("actionZoom_mode")
        self.menuDispZoom = QtWidgets.QAction(MainWindow)
        self.menuDispZoom.setCheckable(True)
        self.menuDispZoom.setObjectName("menuDispZoom")
        self.menuSettingCleanHyp = QtWidgets.QAction(MainWindow)
        self.menuSettingCleanHyp.setObjectName("menuSettingCleanHyp")
        self.menuSaveAnnotations = QtWidgets.QAction(MainWindow)
        self.menuSaveAnnotations.setObjectName("menuSaveAnnotations")
        self.menuLoadAnnotations = QtWidgets.QAction(MainWindow)
        self.menuLoadAnnotations.setObjectName("menuLoadAnnotations")
        self.menuSaveScreenshot = QtWidgets.QAction(MainWindow)
        self.menuSaveScreenshot.setObjectName("menuSaveScreenshot")
        self.menuSaveHypnogram.addAction(self.menuSaveHypnogramData)
        self.menuSaveHypnogram.addAction(self.menuSaveHypnogramFigure)
        self.menuSaveDetections.addAction(self.menuSaveDetectAll)
        self.menuSaveDetections.addAction(self.menuSaveDetectSelected)
        self.menuSave.addAction(self.menuSaveHypnogram.menuAction())
        self.menuSave.addAction(self.menuSaveInfoTable)
        self.menuSave.addAction(self.menuSaveScoringTable)
        self.menuSave.addAction(self.menuSaveDetections.menuAction())
        self.menuSave.addAction(self.menuSaveConfig)
        self.menuSave.addAction(self.menuSaveAnnotations)
        self.menuSave.addAction(self.menuSaveScreenshot)
        self.menuLoadDetections.addAction(self.menuLoadDetectAll)
        self.menuLoadDetections.addAction(self.menuLoadDetectSelect)
        self.menuLoad.addAction(self.menuLoadData)
        self.menuLoad.addAction(self.menuLoadHypno)
        self.menuLoad.addAction(self.menuLoadConfig)
        self.menuLoad.addAction(self.menuLoadDetections.menuAction())
        self.menuLoad.addAction(self.menuLoadAnnotations)
        self.menuFiles.addAction(self.menuSave.menuAction())
        self.menuFiles.addAction(self.menuLoad.menuAction())
        self.menuFiles.addSeparator()
        self.menuFiles.addAction(self.menuExit)
        self.menuDisplay.addAction(self.menuDispSettings)
        self.menuDisplay.addAction(self.menuDispSpec)
        self.menuDisplay.addAction(self.menuDispHypno)
        self.menuDisplay.addAction(self.menuDispTimeax)
        self.menuDisplay.addAction(self.menuDispNavbar)
        self.menuDisplay.addAction(self.menuDispIndic)
        self.menuDisplay.addAction(self.menuDispTopo)
        self.menuDisplay.addAction(self.menuDispZoom)
        self.menubar.addAction(self.menuFiles.menuAction())
        self.menubar.addAction(self.menuDisplay.menuAction())

        self.retranslateUi(MainWindow)
        self.QuickSettings.setCurrentIndex(0)
        self._stacked_panels.setCurrentIndex(0)
        self._PanTopoDisp.setCurrentIndex(0)
        self._stacked_tools.setCurrentIndex(1)
        self._DetectionTab.setCurrentIndex(0)
        self._stacked_detections.setCurrentIndex(2)
        self._slRules.setCurrentIndex(1)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "Sleep"))
        self.QuickSettings.setToolTip(_translate("MainWindow", "<html><head/><body><p><br/></p></body></html>"))
        self.label_77.setText(_translate("MainWindow", "Panel\n"
"type"))
        self._pan_pick.setToolTip(_translate("MainWindow", "<html><head/><body><p>Select the panel type to control</p></body></html>"))
        self._pan_pick.setItemText(0, _translate("MainWindow", "Channels"))
        self._pan_pick.setItemText(1, _translate("MainWindow", "Time-frequency"))
        self._pan_pick.setItemText(2, _translate("MainWindow", "Hypnogram"))
        self._pan_pick.setItemText(3, _translate("MainWindow", "Topoplot"))
        self.groupBox.setToolTip(_translate("MainWindow", "<html><head/><body><p>Select the channels to be displayed and control the amplitudes of each one of them.</p></body></html>"))
        self.groupBox.setTitle(_translate("MainWindow", "Select channels to display"))
        self._PanScrollChan.setToolTip(_translate("MainWindow", "<html><head/><body><p/></body></html>"))
        self.groupBox_7.setTitle(_translate("MainWindow", "Amplitude control"))
        self._PanAllAmpMin.setToolTip(_translate("MainWindow", "<html><head/><body><p>Change minimum amplitude for all channels</p></body></html>"))
        self._PanAllAmpMax.setToolTip(_translate("MainWindow", "<html><head/><body><p>Change maximum amplitude for all channels</p></body></html>"))
        self.label_35.setText(_translate("MainWindow", "Set all amplitudes to: "))
        self._PanAmpAuto.setText(_translate("MainWindow", "Use auto-ajusted amplitudes"))
        self._PanAmpSym.setText(_translate("MainWindow", "Use symetric amplitudes"))
        self._PanChanSelectAll.setToolTip(_translate("MainWindow", "<html><head/><body><p>Display all channels</p></body></html>"))
        self._PanChanSelectAll.setText(_translate("MainWindow", "Display all channels"))
        self._PanChanDeselectAll.setToolTip(_translate("MainWindow", "<html><head/><body><p>Hide all channels</p></body></html>"))
        self._PanChanDeselectAll.setText(_translate("MainWindow", "Hide all channels"))
        self.groupBox_4.setTitle(_translate("MainWindow", "Line"))
        self.label_36.setText(_translate("MainWindow", "Line width"))
        self._channels_alias.setText(_translate("MainWindow", "Antialias"))
        self._PanSpecMethod.setToolTip(_translate("MainWindow", "<html><head/><body><p>Computation method for the spectrogram</p></body></html>"))
        self._PanSpecMethod.setItemText(0, _translate("MainWindow", "Fourier transform"))
        self._PanSpecMethod.setItemText(1, _translate("MainWindow", "Wavelet"))
        self._PanSpecMethod.setItemText(2, _translate("MainWindow", "Multitaper"))
        self.label_54.setText(_translate("MainWindow", "Apply on\n"
"channel"))
        self.label_73.setText(_translate("MainWindow", "Method"))
        self.label_55.setText(_translate("MainWindow", "Settings"))
        self._PanSpecChan.setToolTip(_translate("MainWindow", "<html><head/><body><p>Select the channel on which to compute the spectrogram</p></body></html>"))
        self.label_29.setText(_translate("MainWindow", "Colormap"))
        self._PanSpecCmap.setToolTip(_translate("MainWindow", "<html><head/><body><p>Colormap for the spectrogram</p></body></html>"))
        self._PanSpecCmapInv.setText(_translate("MainWindow", "Reversed"))
        self.label_24.setText(_translate("MainWindow", "Contrast"))
        self._PanSpecCon.setToolTip(_translate("MainWindow", "<html><head/><body><p>Change the contrast of the spectrogram</p></body></html>"))
        self.label_74.setText(_translate("MainWindow", "Interpolation"))
        self._PanSpecInterp.setToolTip(_translate("MainWindow", "<html><head/><body><p>Select to channel used for the spectrogram</p></body></html>"))
        self._PanSpecInterp.setItemText(0, _translate("MainWindow", "nearest"))
        self._PanSpecInterp.setItemText(1, _translate("MainWindow", "bilinear"))
        self._PanSpecInterp.setItemText(2, _translate("MainWindow", "gaussian"))
        self._PanSpecInterp.setItemText(3, _translate("MainWindow", "hanning"))
        self._PanSpecInterp.setItemText(4, _translate("MainWindow", "hamming"))
        self._PanSpecInterp.setItemText(5, _translate("MainWindow", "kaiser"))
        self._PanSpecInterp.setItemText(6, _translate("MainWindow", "quadric"))
        self._PanSpecInterp.setItemText(7, _translate("MainWindow", "bicubic"))
        self._PanSpecInterp.setItemText(8, _translate("MainWindow", "bessel"))
        self._PanSpecInterp.setItemText(9, _translate("MainWindow", "blackman"))
        self.label_15.setText(_translate("MainWindow", "Overlap"))
        self._PanSpecNfft.setToolTip(_translate("MainWindow", "<html><head/><body><p>Length of each time window for computing the spectrogram</p></body></html>"))
        self._PanSpecStep.setToolTip(_translate("MainWindow", "<html><head/><body><p>Overlap between each consecutive windows (e.g 0 mean no overlap and 0,50 mean 50% overlap)</p></body></html>"))
        self.label_16.setText(_translate("MainWindow", "Start"))
        self._PanSpecFstart.setToolTip(_translate("MainWindow", "<html><head/><body><p>Starting frequency for the spectrogram</p></body></html>"))
        self.label_17.setText(_translate("MainWindow", "End"))
        self._PanSpecFend.setToolTip(_translate("MainWindow", "<html><head/><body><p>Ending frequency for the spectrogram</p></body></html>"))
        self.label_14.setText(_translate("MainWindow", "Length"))
        self.label_32.setText(_translate("MainWindow", "Frequencies"))
        self._PanSpecNorm.setToolTip(_translate("MainWindow", "<html><head/><body><p>Select to channel used for the spectrogram</p></body></html>"))
        self._PanSpecNorm.setItemText(0, _translate("MainWindow", "No normalization"))
        self._PanSpecNorm.setItemText(1, _translate("MainWindow", "Subtract the mean"))
        self._PanSpecNorm.setItemText(2, _translate("MainWindow", "Divide by the mean"))
        self._PanSpecNorm.setItemText(3, _translate("MainWindow", "Subtract then divide by the mean"))
        self._PanSpecNorm.setItemText(4, _translate("MainWindow", "Z-score"))
        self.label_75.setText(_translate("MainWindow", "Normalization"))
        self._PanSpecApply.setToolTip(_translate("MainWindow", "<html><head/><body><p>Compute the spectrogram on the selected channel and using the time length, overlap, [fstart, fend], colormap and contrast.</p></body></html>"))
        self._PanSpecApply.setText(_translate("MainWindow", "Apply"))
        self.label_81.setText(_translate("MainWindow", "Linewidth"))
        self._PanHypnoLw.setToolTip(_translate("MainWindow", "Change the line width of the hypnogram [ 1 - 10 ]"))
        self._PanHypnoColor.setToolTip(_translate("MainWindow", "Select whether the hypnogram is displayed in color or in black"))
        self._PanHypnoColor.setText(_translate("MainWindow", "Color"))
        self._PanHypnoReset.setToolTip(_translate("MainWindow", "Reset the hypnogram to an empty one"))
        self._PanHypnoReset.setText(_translate("MainWindow", "Reset hypnogram"))
        self._PanTopoAutoClim.setText(_translate("MainWindow", "Use automatic limits"))
        self.label_66.setText(_translate("MainWindow", "Clim"))
        self.label_63.setText(_translate("MainWindow", "Properties"))
        self.label_69.setText(_translate("MainWindow", "Fmin"))
        self.label_70.setText(_translate("MainWindow", "Fmax"))
        self._PanTopoDisp.setItemText(0, _translate("MainWindow", "power"))
        self._PanTopoDisp.setItemText(1, _translate("MainWindow", "amplitude"))
        self._PanTopoDisp.setItemText(2, _translate("MainWindow", "filter"))
        self.label_65.setText(_translate("MainWindow", "Display"))
        self.label_67.setText(_translate("MainWindow", "Colormap"))
        self._PanTopoRev.setText(_translate("MainWindow", "Inverse"))
        self._PanTopoApply.setText(_translate("MainWindow", "Apply"))
        self.QuickSettings.setTabText(self.QuickSettings.indexOf(self.q_Panels), _translate("MainWindow", "Panels"))
        self.label_78.setText(_translate("MainWindow", "Tool\n"
"type"))
        self._tool_pick.setToolTip(_translate("MainWindow", "<html><head/><body><p>Select the panel type to control</p></body></html>"))
        self._tool_pick.setItemText(0, _translate("MainWindow", "Signal processing"))
        self._tool_pick.setItemText(1, _translate("MainWindow", "Re-referencing"))
        self.label_76.setText(_translate("MainWindow", "Apply preprocessing\n"
"to"))
        self._SigFiltChan.setToolTip(_translate("MainWindow", "<html><head/><body><p>Display the signal, in a specific frequency band as :</p><p>- &quot;filter&quot; : simply, the filtered signal</p><p>- &quot;amplitude&quot; : the amplitude of the signal</p><p>- &quot;power&quot; : the power of the signal</p><p>- &quot;phase&quot; : the phase of the signal</p></body></html>"))
        self._SigFiltChan.setItemText(0, _translate("MainWindow", "all channels"))
        self.groupBox_5.setTitle(_translate("MainWindow", "Mean and trend"))
        self._SigMean.setText(_translate("MainWindow", "Remove mean"))
        self._SigTrend.setText(_translate("MainWindow", "Remove linear trend"))
        self._SigFilt.setTitle(_translate("MainWindow", "Filtering"))
        self._SigFiltDisp.setToolTip(_translate("MainWindow", "<html><head/><body><p>Display the signal, in a specific frequency band as :</p><p>- &quot;filter&quot; : simply, the filtered signal</p><p>- &quot;amplitude&quot; : the amplitude of the signal</p><p>- &quot;power&quot; : the power of the signal</p><p>- &quot;phase&quot; : the phase of the signal</p></body></html>"))
        self._SigFiltDisp.setItemText(0, _translate("MainWindow", "filter"))
        self._SigFiltDisp.setItemText(1, _translate("MainWindow", "amplitude"))
        self._SigFiltDisp.setItemText(2, _translate("MainWindow", "power"))
        self._SigFiltDisp.setItemText(3, _translate("MainWindow", "phase"))
        self.label_18.setText(_translate("MainWindow", "Filter type"))
        self.label_7.setText(_translate("MainWindow", "Frequency"))
        self.label_68.setText(_translate("MainWindow", "Display"))
        self.label_58.setText(_translate("MainWindow", "Settings"))
        self._SigFiltApply.setText(_translate("MainWindow", "Apply"))
        self._SigFiltBand.setToolTip(_translate("MainWindow", "<html><head/><body><p>- bandpass: keep only frequencies between [fmin, fmax]</p><p>- bandstop: remove frequencies between [fmin, fmax]</p><p>- lowpass: keep only frequencies under fmax</p><p>- highpass: keep only frequencies over fmin</p></body></html>"))
        self._SigFiltBand.setItemText(0, _translate("MainWindow", "bandpass"))
        self._SigFiltBand.setItemText(1, _translate("MainWindow", "bandstop"))
        self._SigFiltBand.setItemText(2, _translate("MainWindow", "lowpass"))
        self._SigFiltBand.setItemText(3, _translate("MainWindow", "highpass"))
        self.label_9.setText(_translate("MainWindow", "Fmin"))
        self.label_8.setText(_translate("MainWindow", "Fmax"))
        self.label_10.setText(_translate("MainWindow", "Method"))
        self.label_11.setText(_translate("MainWindow", "order"))
        self._SigFiltOrder.setToolTip(_translate("MainWindow", "<html><head/><body><p>Choose filter order and control narrow band. It is not recommended to use filter order over 3 (can provoc distorsion).</p></body></html>"))
        self._SigFiltMeth.setItemText(0, _translate("MainWindow", "butterworth"))
        self._SigFiltMeth.setItemText(1, _translate("MainWindow", "bessel"))
        self.label_59.setText(_translate("MainWindow", "Warning : re-referencing can only be achieved once"))
        self._ToolsRefIgnore.setToolTip(_translate("MainWindow", "<html><head/><body><p>When this option is checked, channels that are not re-referenced are going to be ignored in the interface  (Ex : if channels is [ O1, O2, O3, Cz, Pz ]  the bipolarized channels will be [ O1, O2-O1, O3-O2, Cz, Pz ] but if this checkbox is activated you will only see the clean version [ O2-O1, 03-O2 ] )</p></body></html>"))
        self._ToolsRefIgnore.setText(_translate("MainWindow", "Remove non-referenced channels"))
        self.label_56.setText(_translate("MainWindow", "Use as  reference"))
        self._ToolsRefLst.setToolTip(_translate("MainWindow", "<html><head/><body><p>Channel to use as the reference</p></body></html>"))
        self.label_60.setText(_translate("MainWindow", "Type"))
        self.label_61.setText(_translate("MainWindow", "Settings"))
        self._ToolsRefIgn.setToolTip(_translate("MainWindow", "<html><head/><body><p>If some channels doesn\'t need to be re-referenced, and if you want to visualize them, be sure to deactivate &quot;Ignore non-referenced channels&quot;</p></body></html>"))
        self._ToolsRefIgn.setText(_translate("MainWindow", "Add channels that don\'t need to be\n"
"re-referenced"))
        self._ToolsRefMeth.setItemText(0, _translate("MainWindow", "Use one channel as reference"))
        self._ToolsRefMeth.setItemText(1, _translate("MainWindow", "Common average"))
        self._ToolsRefMeth.setItemText(2, _translate("MainWindow", "Bipolarization"))
        self._ToolsRefApply.setText(_translate("MainWindow", "Apply"))
        self.QuickSettings.setTabText(self.QuickSettings.indexOf(self.q_Tools), _translate("MainWindow", "Tools"))
        item = self._infoTable.horizontalHeaderItem(0)
        item.setText(_translate("MainWindow", "Infos"))
        item = self._infoTable.horizontalHeaderItem(1)
        item.setText(_translate("MainWindow", "Values"))
        self.QuickSettings.setTabText(self.QuickSettings.indexOf(self.q_Info), _translate("MainWindow", "Infos"))
        self._scoreTable.setSortingEnabled(True)
        item = self._scoreTable.horizontalHeaderItem(0)
        item.setText(_translate("MainWindow", "From (minutes)"))
        item = self._scoreTable.horizontalHeaderItem(1)
        item.setText(_translate("MainWindow", "To (minutes)"))
        item = self._scoreTable.horizontalHeaderItem(2)
        item.setText(_translate("MainWindow", "Stage"))
        self._scoreAdd.setText(_translate("MainWindow", "Add line"))
        self._scoreRm.setText(_translate("MainWindow", "Remove line"))
        self.QuickSettings.setTabText(self.QuickSettings.indexOf(self.q_Score), _translate("MainWindow", "Scoring"))
        self.groupBox_3.setTitle(_translate("MainWindow", "Detection type"))
        self.label_39.setText(_translate("MainWindow", "Type"))
        self.label_25.setText(_translate("MainWindow", "On channel"))
        self._ToolDetectType.setToolTip(_translate("MainWindow", "<html><head/><body><p>Choose the detection type</p></body></html>"))
        self._ToolDetectType.setItemText(0, _translate("MainWindow", "Spindles"))
        self._ToolDetectType.setItemText(1, _translate("MainWindow", "REM"))
        self._ToolDetectType.setItemText(2, _translate("MainWindow", "K-complexes"))
        self._ToolDetectType.setItemText(3, _translate("MainWindow", "Slow waves"))
        self._ToolDetectType.setItemText(4, _translate("MainWindow", "Muscle twitches"))
        self._ToolDetectType.setItemText(5, _translate("MainWindow", "Peaks"))
        self._ToolRdViz.setText(_translate("MainWindow", "Visible"))
        self.label_49.setText(_translate("MainWindow", "Apply\n"
"on"))
        self._ToolRdSelected.setText(_translate("MainWindow", "Selected"))
        self._ToolRdAll.setText(_translate("MainWindow", "All"))
        self._ToolDetectChan.setToolTip(_translate("MainWindow", "<html><head/><body><p>Pick up a channel to run the detection (only avaible with &quot;Selected&quot; option)</p></body></html>"))
        self.groupBox_2.setTitle(_translate("MainWindow", "Settings"))
        self.label_40.setText(_translate("MainWindow", "Threshold"))
        self._ToolSpinTmin.setToolTip(_translate("MainWindow", "<html><head/><body><p>Minimum spindle\'s duration</p></body></html>"))
        self.label_37.setText(_translate("MainWindow", "ms"))
        self._ToolSpinRemOnly.setText(_translate("MainWindow", "Perform detection only for NREM sleep"))
        self._ToolSpinFmin.setToolTip(_translate("MainWindow", "High-pass cutoff frequency"))
        self.label_30.setText(_translate("MainWindow", "Tmax"))
        self.label_22.setText(_translate("MainWindow", "Tmin"))
        self.label_19.setText(_translate("MainWindow", "Fmin"))
        self._ToolSpinFmax.setToolTip(_translate("MainWindow", "Low-pass cutoff frequency"))
        self.label_21.setText(_translate("MainWindow", "Hz"))
        self.label_52.setText(_translate("MainWindow", "Spindles"))
        self._ToolSpinTmax.setToolTip(_translate("MainWindow", "<html><head/><body><p>Maximum spindle\'s duration</p></body></html>"))
        self.label_20.setText(_translate("MainWindow", "Fmax"))
        self._ToolSpinTh.setToolTip(_translate("MainWindow", "<html><head/><body><p>Look for signals having an amplitude \'Threshold\' times superior to the deviation of the filtered signal amplitude</p></body></html>"))
        self._ToolRemTh.setToolTip(_translate("MainWindow", "<html><head/><body><p>Number of standard deviation of the derivative signal</p></body></html>"))
        self.label_38.setText(_translate("MainWindow", "Threshold"))
        self._ToolRemOnly.setText(_translate("MainWindow", "Perform detection only for REM sleep"))
        self.label_51.setText(_translate("MainWindow", "REM"))
        self.label_64.setText(_translate("MainWindow", "Min / Max"))
        self._ToolKCMinAmp.setToolTip(_translate("MainWindow", "Min amplitude of KC"))
        self._ToolKCMaxAmp.setToolTip(_translate("MainWindow", "Max amplitude of KC"))
        self.label_57.setText(_translate("MainWindow", "Proba threshold"))
        self.kc_label.setText(_translate("MainWindow", "K-complexes"))
        self._ToolKCNremOnly.setText(_translate("MainWindow", "Use hypnogram to improve detection"))
        self._ToolKCProbTh.setToolTip(_translate("MainWindow", "Number of standard deviations of the wavelet envelope"))
        self.label_62.setText(_translate("MainWindow", "Tmin / Tmax"))
        self._ToolKCMinDur.setToolTip(_translate("MainWindow", "<html><head/><body><p>Minimum duration of KC (ms)</p></body></html>"))
        self._ToolKCMaxDur.setToolTip(_translate("MainWindow", "<html><head/><body><p>Maximum duration of KC (ms)</p></body></html>"))
        self.label_71.setText(_translate("MainWindow", "Amp threshold"))
        self.label_53.setText(_translate("MainWindow", "Slow waves"))
        self._ToolWaveTh.setToolTip(_translate("MainWindow", "<html><head/><body><p>Normalized Delta power threshold (between 0 and 1) </p></body></html>"))
        self.label_46.setText(_translate("MainWindow", "Delta power (norm.)"))
        self._ToolMTTh.setToolTip(_translate("MainWindow", "<html><head/><body><p>Number of standard deviation of the derivative signal</p></body></html>"))
        self.label_93.setText(_translate("MainWindow", "Threshold"))
        self._ToolMTOnly.setText(_translate("MainWindow", "Perform detection only for REM sleep"))
        self.label_94.setText(_translate("MainWindow", "Muscle\n"
"Twitches"))
        self.label_26.setText(_translate("MainWindow", "Lookahead"))
        self._ToolPeakLook.setToolTip(_translate("MainWindow", "<html><head/><body><p>Minimum distance between two peaks</p></body></html>"))
        self.label_28.setText(_translate("MainWindow", "Display"))
        self.label_27.setText(_translate("MainWindow", "seconds"))
        self._ToolPeakMinMax.setToolTip(_translate("MainWindow", "<html><head/><body><p>Search either for maximum / minimum / both</p></body></html>"))
        self._ToolPeakMinMax.setItemText(0, _translate("MainWindow", "Max only"))
        self._ToolPeakMinMax.setItemText(1, _translate("MainWindow", "Min only"))
        self._ToolPeakMinMax.setItemText(2, _translate("MainWindow", "Min and Max"))
        self.label_50.setText(_translate("MainWindow", "Peak"))
        item = self._ToolDetectTable.horizontalHeaderItem(0)
        item.setText(_translate("MainWindow", "Number"))
        item = self._ToolDetectTable.horizontalHeaderItem(1)
        item.setText(_translate("MainWindow", "Density ( / min )"))
        self._ToolDetectApply.setToolTip(_translate("MainWindow", "<html><head/><body><p>Apply detection either on :</p><p>- Selected channels via the channel selection box above</p><p>- Visible channels</p><p>- All channels</p></body></html>"))
        self._ToolDetectApply.setText(_translate("MainWindow", "Apply"))
        self._DetectionTab.setTabText(self._DetectionTab.indexOf(self.q_DetectSettings), _translate("MainWindow", "Settings"))
        self.label_72.setText(_translate("MainWindow", "Select which\n"
"detection to\n"
"display"))
        self._DetectViz.setText(_translate("MainWindow", "Visible"))
        self._DetectRm.setText(_translate("MainWindow", "Remove"))
        self._DetectLocations.setSortingEnabled(True)
        item = self._DetectLocations.horizontalHeaderItem(0)
        item.setText(_translate("MainWindow", "Start (sec)"))
        item = self._DetectLocations.horizontalHeaderItem(1)
        item.setText(_translate("MainWindow", "End (sec)"))
        item = self._DetectLocations.horizontalHeaderItem(2)
        item.setText(_translate("MainWindow", "Duration (ms)"))
        item = self._DetectLocations.horizontalHeaderItem(3)
        item.setText(_translate("MainWindow", "Stage"))
        self._DetecRmEvent.setText(_translate("MainWindow", "Remove selected event"))
        self._DetectionTab.setTabText(self._DetectionTab.indexOf(self.q_DetectLoc), _translate("MainWindow", "Locations"))
        self.QuickSettings.setTabText(self.QuickSettings.indexOf(self.q_Detection), _translate("MainWindow", "Detection"))
        self._AnnotateTable.setSortingEnabled(True)
        item = self._AnnotateTable.horizontalHeaderItem(0)
        item.setText(_translate("MainWindow", "Start (seconds)"))
        item = self._AnnotateTable.horizontalHeaderItem(1)
        item.setText(_translate("MainWindow", "End (seconds)"))
        item = self._AnnotateTable.horizontalHeaderItem(2)
        item.setText(_translate("MainWindow", "Text"))
        self._AnnotateAdd.setText(_translate("MainWindow", "Annotate"))
        self._AnnotateRm.setText(_translate("MainWindow", "Remove selected line"))
        self.QuickSettings.setTabText(self.QuickSettings.indexOf(self.tab), _translate("MainWindow", "Annotations"))
        self._topoTitle.setText(_translate("MainWindow", "topotitle"))
        self._slRules.setItemText(0, _translate("MainWindow", "seconds"))
        self._slRules.setItemText(1, _translate("MainWindow", "minutes"))
        self._slRules.setItemText(2, _translate("MainWindow", "hours"))
        self._txtCursor.setText(_translate("MainWindow", "[...]"))
        self._SlText.setText(_translate("MainWindow", "TextLabel"))
        self._AnnotateRun.setText(_translate("MainWindow", "Annotate"))
        self.label_2.setText(_translate("MainWindow", "nV gridline"))
        self._slMagnify.setText(_translate("MainWindow", "Magnify"))
        self.label_12.setText(_translate("MainWindow", "sec"))
        self.label.setText(_translate("MainWindow", "Go to"))
        self.label_3.setText(_translate("MainWindow", "Window"))
        self.label_5.setText(_translate("MainWindow", "Slider step"))
        self._slAbsTime.setText(_translate("MainWindow", "Abs. Time"))
        self._slGrid.setText(_translate("MainWindow", "Grid"))
        self.label_4.setText(_translate("MainWindow", "sec"))
        self.label_31.setText(_translate("MainWindow", "Rule"))
        self.label_6.setText(_translate("MainWindow", "sec"))
        self._slStageColors.setText(_translate("MainWindow", "Stage colors"))
        self.menuFiles.setTitle(_translate("MainWindow", "Files"))
        self.menuSave.setTitle(_translate("MainWindow", "Save"))
        self.menuSaveHypnogram.setTitle(_translate("MainWindow", "Hypnogram"))
        self.menuSaveDetections.setTitle(_translate("MainWindow", "Detection"))
        self.menuLoad.setTitle(_translate("MainWindow", "Load"))
        self.menuLoadDetections.setTitle(_translate("MainWindow", "Detections"))
        self.menuDisplay.setTitle(_translate("MainWindow", "View"))
        self.actionSave.setText(_translate("MainWindow", "Save"))
        self.actionLoad.setText(_translate("MainWindow", "Load"))
        self.actionCortical_repartition.setText(_translate("MainWindow", "Cortical repartition"))
        self.actionCortical.setText(_translate("MainWindow", "Cortical"))
        self.actionSagittal.setText(_translate("MainWindow", "Sagittal"))
        self.actionAxial.setText(_translate("MainWindow", "Axial"))
        self.actionCamera.setText(_translate("MainWindow", "Camera"))
        self.actionLeft.setText(_translate("MainWindow", "Left"))
        self.actionRight.setText(_translate("MainWindow", "Right"))
        self.menuDispSettings.setText(_translate("MainWindow", "Quick settings"))
        self.menuDispSettings.setShortcut(_translate("MainWindow", "Ctrl+D"))
        self.actionClose.setText(_translate("MainWindow", "Close"))
        self.actionClose.setShortcut(_translate("MainWindow", "Ctrl+Q"))
        self.actionProjection.setText(_translate("MainWindow", "Projection"))
        self.actionProjection.setToolTip(_translate("MainWindow", "<html><head/><body><p>Find all vertices under a distance of t_radius with each source and project s_data to the surface</p></body></html>"))
        self.actionProjection.setShortcut(_translate("MainWindow", "Ctrl+P"))
        self.actionRepartition.setText(_translate("MainWindow", "Repartition"))
        self.actionRepartition.setShortcut(_translate("MainWindow", "Ctrl+R"))
        self.actionShortcuts.setText(_translate("MainWindow", "Shortcuts"))
        self.actionShortcuts.setShortcut(_translate("MainWindow", "Ctrl+T"))
        self.actionUi_settings.setText(_translate("MainWindow", "Ui settings"))
        self.actionNdPlt.setText(_translate("MainWindow", "Nd-plot"))
        self.actionOnedPlt.setText(_translate("MainWindow", "1d-plot"))
        self.actionImage.setText(_translate("MainWindow", "Image"))
        self.actionColormap.setText(_translate("MainWindow", "Colormap"))
        self.menuShortcut.setText(_translate("MainWindow", "Shortcuts"))
        self.menuShortcut.setShortcut(_translate("MainWindow", "Ctrl+T"))
        self.menuDocumentation.setText(_translate("MainWindow", "Documentation"))
        self.menuDocumentation.setShortcut(_translate("MainWindow", "Ctrl+E"))
        self.actionScreenshot.setText(_translate("MainWindow", "Screenshot"))
        self.actionScreenshot.setShortcut(_translate("MainWindow", "Ctrl+N"))
        self.actionSave_hypnogram.setText(_translate("MainWindow", "Save hypnogram data"))
        self.actionSave_infos.setText(_translate("MainWindow", "Save infos table"))
        self.actionSave_scoring.setText(_translate("MainWindow", "Save scoring table"))
        self.actionSave_detection.setText(_translate("MainWindow", "Save detection table"))
        self.actionSave_all.setText(_translate("MainWindow", "Save all"))
        self.menuExit.setText(_translate("MainWindow", "Exit"))
        self.menuExit.setShortcut(_translate("MainWindow", "Ctrl+Q"))
        self.actionLoad_hypnogram.setText(_translate("MainWindow", "Load hypnogram"))
        self.menuSaveInfoTable.setText(_translate("MainWindow", "Stats info table"))
        self.menuSaveScoringTable.setText(_translate("MainWindow", "Scoring table"))
        self.actionAll.setText(_translate("MainWindow", "All"))
        self.actionAll.setShortcut(_translate("MainWindow", "Ctrl+S"))
        self.menuLoadHypno.setText(_translate("MainWindow", "Hypnogram"))
        self.menuLoadData.setText(_translate("MainWindow", "Data"))
        self.actionHypnogram_figure.setText(_translate("MainWindow", "Hypnogram figure"))
        self.menuLoadConfig.setText(_translate("MainWindow", "GUI config"))
        self.menuSaveConfig.setText(_translate("MainWindow", "GUI config"))
        self.menuDownload_pdf_doc.setText(_translate("MainWindow", "Download pdf doc"))
        self.menuSaveHypnogramFigure.setText(_translate("MainWindow", "Figure"))
        self.menuSaveHypnogramData.setText(_translate("MainWindow", "Data"))
        self.menuSaveDetectAll.setText(_translate("MainWindow", "All detections"))
        self.menuSaveDetectSelected.setText(_translate("MainWindow", "Selected detection"))
        self.menuSaveScreenshotEntire.setText(_translate("MainWindow", "Entire window"))
        self.menuSaveScreenshotSelected.setText(_translate("MainWindow", "Selected canvas"))
        self.menuLoadDetectAll.setText(_translate("MainWindow", "All"))
        self.menuLoadDetectSelect.setText(_translate("MainWindow", "Selected"))
        self.menuDispSpec.setText(_translate("MainWindow", "Spectrogram"))
        self.menuDispSpec.setShortcut(_translate("MainWindow", "S"))
        self.menuDispHypno.setText(_translate("MainWindow", "Hypnogram"))
        self.menuDispHypno.setShortcut(_translate("MainWindow", "H"))
        self.menuDispNavbar.setText(_translate("MainWindow", "Navigation bar"))
        self.menuDispNavbar.setShortcut(_translate("MainWindow", "P"))
        self.menuDispTimeax.setText(_translate("MainWindow", "Time axis"))
        self.menuDispTimeax.setShortcut(_translate("MainWindow", "X"))
        self.menuDispTopo.setText(_translate("MainWindow", "Topoplot"))
        self.menuDispTopo.setShortcut(_translate("MainWindow", "T"))
        self.menuDispIndic.setText(_translate("MainWindow", "Time indicators"))
        self.menuDispIndic.setShortcut(_translate("MainWindow", "I"))
        self.actionZoom_mode.setText(_translate("MainWindow", "Zoom mode"))
        self.actionZoom_mode.setShortcut(_translate("MainWindow", "Z"))
        self.menuDispZoom.setText(_translate("MainWindow", "Zoom mode"))
        self.menuDispZoom.setShortcut(_translate("MainWindow", "Z"))
        self.menuSettingCleanHyp.setText(_translate("MainWindow", "Clean hypnogram"))
        self.menuSaveAnnotations.setText(_translate("MainWindow", "Annotation"))
        self.menuLoadAnnotations.setText(_translate("MainWindow", "Annotations"))
        self.menuSaveScreenshot.setText(_translate("MainWindow", "Screenshot"))
        self.menuSaveScreenshot.setShortcut(_translate("MainWindow", "Ctrl+N"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    MainWindow = QtWidgets.QMainWindow()
    ui = Ui_MainWindow()
    ui.setupUi(MainWindow)
    MainWindow.show()
    sys.exit(app.exec_())
